@@ -52,13 +52,13 @@ static const GimpActionEntry tools_actions[] =
 
 static const GimpStringActionEntry tools_alternative_actions[] =
 {
-  { "tools-by-color-select-short", GIMP_STOCK_TOOL_BY_COLOR_SELECT,
+  { "tools-by-color-select-short", GIMP_ICON_TOOL_BY_COLOR_SELECT,
     NC_("tools-action", "_By Color"), NULL,
     NC_("tools-action", "Select regions with similar colors"),
     "gimp-by-color-select-tool",
     GIMP_HELP_TOOL_BY_COLOR_SELECT },
 
-  { "tools-rotate-arbitrary", GIMP_STOCK_TOOL_ROTATE,
+  { "tools-rotate-arbitrary", GIMP_ICON_TOOL_ROTATE,
     NC_("tools-action", "_Arbitrary Rotation..."), "",
     NC_("tools-action", "Rotate by an arbitrary angle"),
     "gimp-rotate-layer",
@@ -67,7 +67,7 @@ static const GimpStringActionEntry tools_alternative_actions[] =
 
 static const GimpEnumActionEntry tools_color_average_radius_actions[] =
 {
-  { "tools-color-average-radius-set", GIMP_STOCK_TOOL_COLOR_PICKER,
+  { "tools-color-average-radius-set", GIMP_ICON_TOOL_COLOR_PICKER,
     "Set Color Picker Radius", NULL, NULL,
     GIMP_ACTION_SELECT_SET, TRUE,
     NULL }
@@ -75,7 +75,7 @@ static const GimpEnumActionEntry tools_color_average_radius_actions[] =
 
 static const GimpEnumActionEntry tools_paintbrush_size_actions[] =
 {
-  { "tools-paintbrush-size-set", GIMP_STOCK_TOOL_PAINTBRUSH,
+  { "tools-paintbrush-size-set", GIMP_ICON_TOOL_PAINTBRUSH,
     "Set Brush Size", NULL, NULL,
     GIMP_ACTION_SELECT_SET, TRUE,
     NULL }
@@ -83,7 +83,7 @@ static const GimpEnumActionEntry tools_paintbrush_size_actions[] =
 
 static const GimpEnumActionEntry tools_paintbrush_aspect_ratio_actions[] =
 {
-  { "tools-paintbrush-aspect-ratio-set", GIMP_STOCK_TOOL_PAINTBRUSH,
+  { "tools-paintbrush-aspect-ratio-set", GIMP_ICON_TOOL_PAINTBRUSH,
     "Set Brush Aspect Ratio", NULL, NULL,
     GIMP_ACTION_SELECT_SET, TRUE,
     NULL }
@@ -91,7 +91,7 @@ static const GimpEnumActionEntry tools_paintbrush_aspect_ratio_actions[] =
 
 static const GimpEnumActionEntry tools_paintbrush_angle_actions[] =
 {
-  { "tools-paintbrush-angle-set", GIMP_STOCK_TOOL_PAINTBRUSH,
+  { "tools-paintbrush-angle-set", GIMP_ICON_TOOL_PAINTBRUSH,
     "Set Brush Angle", NULL, NULL,
     GIMP_ACTION_SELECT_SET, TRUE,
     NULL }
@@ -99,7 +99,7 @@ static const GimpEnumActionEntry tools_paintbrush_angle_actions[] =
 
 static const GimpEnumActionEntry tools_paintbrush_spacing_actions[] =
 {
-  { "tools-paintbrush-spacing-set", GIMP_STOCK_TOOL_PAINTBRUSH,
+  { "tools-paintbrush-spacing-set", GIMP_ICON_TOOL_PAINTBRUSH,
     "Set Brush Spacing", NULL, NULL,
     GIMP_ACTION_SELECT_SET, TRUE,
     NULL }
@@ -107,7 +107,7 @@ static const GimpEnumActionEntry tools_paintbrush_spacing_actions[] =
 
 static const GimpEnumActionEntry tools_paintbrush_hardness_actions[] =
 {
-  { "tools-paintbrush-hardness-set", GIMP_STOCK_TOOL_PAINTBRUSH,
+  { "tools-paintbrush-hardness-set", GIMP_ICON_TOOL_PAINTBRUSH,
     "Set Brush Hardness", NULL, NULL,
     GIMP_ACTION_SELECT_SET, TRUE,
     NULL }
@@ -115,7 +115,7 @@ static const GimpEnumActionEntry tools_paintbrush_hardness_actions[] =
 
 static const GimpEnumActionEntry tools_paintbrush_force_actions[] =
 {
-  { "tools-paintbrush-force-set", GIMP_STOCK_TOOL_PAINTBRUSH,
+  { "tools-paintbrush-force-set", GIMP_ICON_TOOL_PAINTBRUSH,
     "Set Brush Force", NULL, NULL,
     GIMP_ACTION_SELECT_SET, TRUE,
     NULL }
@@ -123,7 +123,7 @@ static const GimpEnumActionEntry tools_paintbrush_force_actions[] =
 
 static const GimpEnumActionEntry tools_ink_blob_size_actions[] =
 {
-  { "tools-ink-blob-size-set", GIMP_STOCK_TOOL_INK,
+  { "tools-ink-blob-size-set", GIMP_ICON_TOOL_INK,
     "Set Ink Blob Size", NULL, NULL,
     GIMP_ACTION_SELECT_SET, TRUE,
     NULL }
@@ -131,7 +131,7 @@ static const GimpEnumActionEntry tools_ink_blob_size_actions[] =
 
 static const GimpEnumActionEntry tools_ink_blob_aspect_actions[] =
 {
-  { "tools-ink-blob-aspect-set", GIMP_STOCK_TOOL_INK,
+  { "tools-ink-blob-aspect-set", GIMP_ICON_TOOL_INK,
     "Set Ink Blob Aspect", NULL, NULL,
     GIMP_ACTION_SELECT_SET, TRUE,
     NULL }
@@ -139,7 +139,7 @@ static const GimpEnumActionEntry tools_ink_blob_aspect_actions[] =
 
 static const GimpEnumActionEntry tools_ink_blob_angle_actions[] =
 {
-  { "tools-ink-blob-angle-set", GIMP_STOCK_TOOL_INK,
+  { "tools-ink-blob-angle-set", GIMP_ICON_TOOL_INK,
     "Set Ink Blob Angle", NULL, NULL,
     GIMP_ACTION_SELECT_SET, TRUE,
     NULL }
@@ -147,31 +147,31 @@ static const GimpEnumActionEntry tools_ink_blob_angle_actions[] =
 
 static const GimpEnumActionEntry tools_airbrush_rate_actions[] =
 {
-  { "tools-airbrush-rate-set", GIMP_STOCK_TOOL_AIRBRUSH,
+  { "tools-airbrush-rate-set", GIMP_ICON_TOOL_AIRBRUSH,
     "Set Airrush Rate", NULL, NULL,
     GIMP_ACTION_SELECT_SET, TRUE,
     NULL },
-  { "tools-airbrush-rate-minimum", GIMP_STOCK_TOOL_AIRBRUSH,
+  { "tools-airbrush-rate-minimum", GIMP_ICON_TOOL_AIRBRUSH,
     "Minimum Rate", NULL, NULL,
     GIMP_ACTION_SELECT_FIRST, FALSE,
     NULL },
-  { "tools-airbrush-rate-maximum", GIMP_STOCK_TOOL_AIRBRUSH,
+  { "tools-airbrush-rate-maximum", GIMP_ICON_TOOL_AIRBRUSH,
     "Maximum Rate", NULL, NULL,
     GIMP_ACTION_SELECT_LAST, FALSE,
     NULL },
-  { "tools-airbrush-rate-decrease", GIMP_STOCK_TOOL_AIRBRUSH,
+  { "tools-airbrush-rate-decrease", GIMP_ICON_TOOL_AIRBRUSH,
     "Decrease Rate", NULL, NULL,
     GIMP_ACTION_SELECT_PREVIOUS, FALSE,
     NULL },
-  { "tools-airbrush-rate-increase", GIMP_STOCK_TOOL_AIRBRUSH,
+  { "tools-airbrush-rate-increase", GIMP_ICON_TOOL_AIRBRUSH,
     "Increase Rate", NULL, NULL,
     GIMP_ACTION_SELECT_NEXT, FALSE,
     NULL },
-  { "tools-airbrush-rate-decrease-skip", GIMP_STOCK_TOOL_AIRBRUSH,
+  { "tools-airbrush-rate-decrease-skip", GIMP_ICON_TOOL_AIRBRUSH,
     "Decrease Rate More", NULL, NULL,
     GIMP_ACTION_SELECT_SKIP_PREVIOUS, FALSE,
     NULL },
-  { "tools-airbrush-rate-increase-skip", GIMP_STOCK_TOOL_AIRBRUSH,
+  { "tools-airbrush-rate-increase-skip", GIMP_ICON_TOOL_AIRBRUSH,
     "Increase Rate More", NULL, NULL,
     GIMP_ACTION_SELECT_SKIP_NEXT, FALSE,
     NULL }
@@ -179,31 +179,31 @@ static const GimpEnumActionEntry tools_airbrush_rate_actions[] =
 
 static const GimpEnumActionEntry tools_airbrush_flow_actions[] =
 {
-  { "tools-airbrush-flow-set", GIMP_STOCK_TOOL_AIRBRUSH,
+  { "tools-airbrush-flow-set", GIMP_ICON_TOOL_AIRBRUSH,
     "Set Airrush Flow", NULL, NULL,
     GIMP_ACTION_SELECT_SET, TRUE,
     NULL },
-  { "tools-airbrush-flow-minimum", GIMP_STOCK_TOOL_AIRBRUSH,
+  { "tools-airbrush-flow-minimum", GIMP_ICON_TOOL_AIRBRUSH,
     "Minimum Flow", NULL, NULL,
     GIMP_ACTION_SELECT_FIRST, FALSE,
     NULL },
-  { "tools-airbrush-flow-maximum", GIMP_STOCK_TOOL_AIRBRUSH,
+  { "tools-airbrush-flow-maximum", GIMP_ICON_TOOL_AIRBRUSH,
     "Maximum Flow", NULL, NULL,
     GIMP_ACTION_SELECT_LAST, FALSE,
     NULL },
-  { "tools-airbrush-flow-decrease", GIMP_STOCK_TOOL_AIRBRUSH,
+  { "tools-airbrush-flow-decrease", GIMP_ICON_TOOL_AIRBRUSH,
     "Decrease Flow", NULL, NULL,
     GIMP_ACTION_SELECT_PREVIOUS, FALSE,
     NULL },
-  { "tools-airbrush-flow-increase", GIMP_STOCK_TOOL_AIRBRUSH,
+  { "tools-airbrush-flow-increase", GIMP_ICON_TOOL_AIRBRUSH,
     "Increase Flow", NULL, NULL,
     GIMP_ACTION_SELECT_NEXT, FALSE,
     NULL },
-  { "tools-airbrush-flow-decrease-skip", GIMP_STOCK_TOOL_AIRBRUSH,
+  { "tools-airbrush-flow-decrease-skip", GIMP_ICON_TOOL_AIRBRUSH,
     "Decrease Flow More", NULL, NULL,
     GIMP_ACTION_SELECT_SKIP_PREVIOUS, FALSE,
     NULL },
-  { "tools-airbrush-flow-increase-skip", GIMP_STOCK_TOOL_AIRBRUSH,
+  { "tools-airbrush-flow-increase-skip", GIMP_ICON_TOOL_AIRBRUSH,
     "Increase Flow More", NULL, NULL,
     GIMP_ACTION_SELECT_SKIP_NEXT, FALSE,
     NULL }
@@ -211,7 +211,7 @@ static const GimpEnumActionEntry tools_airbrush_flow_actions[] =
 
 static const GimpEnumActionEntry tools_mybrush_radius_actions[] =
 {
-  { "tools-mypaint-brush-radius-set", GIMP_STOCK_TOOL_MYPAINT_BRUSH,
+  { "tools-mypaint-brush-radius-set", GIMP_ICON_TOOL_MYPAINT_BRUSH,
     "Set MyPaint Brush Radius", NULL, NULL,
     GIMP_ACTION_SELECT_SET, TRUE,
     NULL }
@@ -219,7 +219,7 @@ static const GimpEnumActionEntry tools_mybrush_radius_actions[] =
 
 static const GimpEnumActionEntry tools_mybrush_hardness_actions[] =
 {
-  { "tools-mypaint-brush-hardness-set", GIMP_STOCK_TOOL_MYPAINT_BRUSH,
+  { "tools-mypaint-brush-hardness-set", GIMP_ICON_TOOL_MYPAINT_BRUSH,
     "Set MyPaint Brush Hardness", NULL, NULL,
     GIMP_ACTION_SELECT_SET, TRUE,
     NULL }
@@ -228,7 +228,7 @@ static const GimpEnumActionEntry tools_mybrush_hardness_actions[] =
 static const GimpEnumActionEntry tools_foreground_select_brush_size_actions[] =
 {
   { "tools-foreground-select-brush-size-set",
-    GIMP_STOCK_TOOL_FOREGROUND_SELECT,
+    GIMP_ICON_TOOL_FOREGROUND_SELECT,
     "Set Foreground Select Brush Size", NULL, NULL,
     GIMP_ACTION_SELECT_SET, TRUE,
     NULL }
@@ -236,7 +236,7 @@ static const GimpEnumActionEntry tools_foreground_select_brush_size_actions[] =
 
 static const GimpEnumActionEntry tools_transform_preview_opacity_actions[] =
 {
-  { "tools-transform-preview-opacity-set", GIMP_STOCK_TOOL_PERSPECTIVE,
+  { "tools-transform-preview-opacity-set", GIMP_ICON_TOOL_PERSPECTIVE,
     "Set Transform Tool Preview Opacity", NULL, NULL,
     GIMP_ACTION_SELECT_SET, TRUE,
     NULL }
@@ -244,8 +244,7 @@ static const GimpEnumActionEntry tools_transform_preview_opacity_actions[] =
 
 static const GimpEnumActionEntry tools_warp_effect_size_actions[] =
 {
-  { "tools-warp-effect-size-set",
-    GIMP_STOCK_TOOL_WARP,
+  { "tools-warp-effect-size-set", GIMP_ICON_TOOL_WARP,
     "Set Warp Effect Size", NULL, NULL,
     GIMP_ACTION_SELECT_SET, TRUE,
     NULL }
@@ -253,8 +252,7 @@ static const GimpEnumActionEntry tools_warp_effect_size_actions[] =
 
 static const GimpEnumActionEntry tools_warp_effect_hardness_actions[] =
 {
-  { "tools-warp-effect-hardness-set",
-    GIMP_STOCK_TOOL_WARP,
+  { "tools-warp-effect-hardness-set", GIMP_ICON_TOOL_WARP,
     "Set Warp Effect Hardness", NULL, NULL,
     GIMP_ACTION_SELECT_SET, TRUE,
     NULL }
@@ -262,43 +260,43 @@ static const GimpEnumActionEntry tools_warp_effect_hardness_actions[] =
 
 static const GimpEnumActionEntry tools_opacity_actions[] =
 {
-  { "tools-opacity-set", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-opacity-set", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Set Opacity", NULL, NULL,
     GIMP_ACTION_SELECT_SET, TRUE,
     NULL },
-  { "tools-opacity-set-to-default", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-opacity-set-to-default", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Set Opacity To Default Value", NULL, NULL,
     GIMP_ACTION_SELECT_SET_TO_DEFAULT, FALSE,
     NULL },
-  { "tools-opacity-minimum", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-opacity-minimum", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Minimize Opacity", NULL, NULL,
     GIMP_ACTION_SELECT_FIRST, FALSE,
     NULL },
-  { "tools-opacity-maximum", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-opacity-maximum", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Maximize Opacity", NULL, NULL,
     GIMP_ACTION_SELECT_LAST, FALSE,
     NULL },
-  { "tools-opacity-decrease", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-opacity-decrease", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Decrease Opacity", "less", NULL,
     GIMP_ACTION_SELECT_PREVIOUS, FALSE,
     NULL },
-  { "tools-opacity-increase", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-opacity-increase", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Increase Opacity", "greater", NULL,
     GIMP_ACTION_SELECT_NEXT, FALSE,
     NULL },
-  { "tools-opacity-decrease-skip", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-opacity-decrease-skip", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Decrease Opacity More", "<primary>less", NULL,
     GIMP_ACTION_SELECT_SKIP_PREVIOUS, FALSE,
     NULL },
-  { "tools-opacity-increase-skip", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-opacity-increase-skip", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Increase Opacity More", "<primary>greater", NULL,
     GIMP_ACTION_SELECT_SKIP_NEXT, FALSE,
     NULL },
-  { "tools-opacity-decrease-percent", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-opacity-decrease-percent", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Decrease Opacity Relative", NULL, NULL,
     GIMP_ACTION_SELECT_PERCENT_PREVIOUS, FALSE,
     NULL },
-  { "tools-opacity-increase-percent", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-opacity-increase-percent", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Increase Opacity Relative", NULL, NULL,
     GIMP_ACTION_SELECT_PERCENT_NEXT, FALSE,
     NULL },
@@ -306,43 +304,43 @@ static const GimpEnumActionEntry tools_opacity_actions[] =
 
 static const GimpEnumActionEntry tools_size_actions[] =
 {
-  { "tools-size-set", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-size-set", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Set Size", NULL, NULL,
     GIMP_ACTION_SELECT_SET, TRUE,
     NULL },
-  { "tools-size-set-to-default", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-size-set-to-default", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Set Size To Default Value", "backslash", NULL,
     GIMP_ACTION_SELECT_SET_TO_DEFAULT, FALSE,
     NULL },
-  { "tools-size-minimum", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-size-minimum", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Minimize Size", NULL, NULL,
     GIMP_ACTION_SELECT_FIRST, FALSE,
     NULL },
-  { "tools-size-maximum", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-size-maximum", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Maximize Size", NULL, NULL,
     GIMP_ACTION_SELECT_LAST, FALSE,
     NULL },
-  { "tools-size-decrease", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-size-decrease", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Decrease Size", "bracketleft", NULL,
     GIMP_ACTION_SELECT_PREVIOUS, FALSE,
     NULL },
-  { "tools-size-increase", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-size-increase", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Increase Size", "bracketright", NULL,
     GIMP_ACTION_SELECT_NEXT, FALSE,
     NULL },
-  { "tools-size-decrease-skip", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-size-decrease-skip", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Decrease Size More", "<shift>bracketleft", NULL,
     GIMP_ACTION_SELECT_SKIP_PREVIOUS, FALSE,
     NULL },
-  { "tools-size-increase-skip", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-size-increase-skip", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Increase Size More", "<shift>bracketright", NULL,
     GIMP_ACTION_SELECT_SKIP_NEXT, FALSE,
     NULL },
-  { "tools-size-decrease-percent", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-size-decrease-percent", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Decrease Size Relative", NULL, NULL,
     GIMP_ACTION_SELECT_PERCENT_PREVIOUS, FALSE,
     NULL },
-  { "tools-size-increase-percent", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-size-increase-percent", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Increase Size Relative", NULL, NULL,
     GIMP_ACTION_SELECT_PERCENT_NEXT, FALSE,
     NULL },
@@ -350,43 +348,43 @@ static const GimpEnumActionEntry tools_size_actions[] =
 
 static const GimpEnumActionEntry tools_aspect_actions[] =
 {
-  { "tools-aspect-set", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-aspect-set", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Set Aspect Ratio", NULL, NULL,
     GIMP_ACTION_SELECT_SET, TRUE,
     NULL },
-  { "tools-aspect-set-to-default", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-aspect-set-to-default", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Set Aspect Ratio To Default Value", NULL, NULL,
     GIMP_ACTION_SELECT_SET_TO_DEFAULT, FALSE,
     NULL },
-  { "tools-aspect-minimum", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-aspect-minimum", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Minimize Aspect Ratio", NULL, NULL,
     GIMP_ACTION_SELECT_FIRST, FALSE,
     NULL },
-  { "tools-aspect-maximum", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-aspect-maximum", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Maximize Aspect Ratio", NULL, NULL,
     GIMP_ACTION_SELECT_LAST, FALSE,
     NULL },
-  { "tools-aspect-decrease", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-aspect-decrease", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Decrease Aspect Ratio", NULL, NULL,
     GIMP_ACTION_SELECT_PREVIOUS, FALSE,
     NULL },
-  { "tools-aspect-increase", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-aspect-increase", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Increase Aspect Ratio", NULL, NULL,
     GIMP_ACTION_SELECT_NEXT, FALSE,
     NULL },
-  { "tools-aspect-decrease-skip", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-aspect-decrease-skip", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Decrease Aspect Ratio More", NULL, NULL,
     GIMP_ACTION_SELECT_SKIP_PREVIOUS, FALSE,
     NULL },
-  { "tools-aspect-increase-skip", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-aspect-increase-skip", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Increase Aspect Ratio More", NULL, NULL,
     GIMP_ACTION_SELECT_SKIP_NEXT, FALSE,
     NULL },
-  { "tools-aspect-decrease-percent", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-aspect-decrease-percent", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Decrease Aspect Ratio Relative", NULL, NULL,
     GIMP_ACTION_SELECT_PERCENT_PREVIOUS, FALSE,
     NULL },
-  { "tools-aspect-increase-percent", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-aspect-increase-percent", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Increase Aspect Ratio Relative", NULL, NULL,
     GIMP_ACTION_SELECT_PERCENT_NEXT, FALSE,
     NULL },
@@ -394,43 +392,43 @@ static const GimpEnumActionEntry tools_aspect_actions[] =
 
 static const GimpEnumActionEntry tools_angle_actions[] =
 {
-  { "tools-angle-set", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-angle-set", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Set Angle", NULL, NULL,
     GIMP_ACTION_SELECT_SET, TRUE,
     NULL },
-  { "tools-angle-set-to-default", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-angle-set-to-default", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Set Angle To Default Value", NULL, NULL,
     GIMP_ACTION_SELECT_SET_TO_DEFAULT, FALSE,
     NULL },
-  { "tools-angle-minimum", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-angle-minimum", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Minimize Angle", NULL, NULL,
     GIMP_ACTION_SELECT_FIRST, FALSE,
     NULL },
-  { "tools-angle-maximum", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-angle-maximum", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Maximize Angle", NULL, NULL,
     GIMP_ACTION_SELECT_LAST, FALSE,
     NULL },
-  { "tools-angle-decrease", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-angle-decrease", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Decrease Angle", NULL, NULL,
     GIMP_ACTION_SELECT_PREVIOUS, FALSE,
     NULL },
-  { "tools-angle-increase", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-angle-increase", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Increase Angle", NULL, NULL,
     GIMP_ACTION_SELECT_NEXT, FALSE,
     NULL },
-  { "tools-angle-decrease-skip", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-angle-decrease-skip", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Decrease Angle More", NULL, NULL,
     GIMP_ACTION_SELECT_SKIP_PREVIOUS, FALSE,
     NULL },
-  { "tools-angle-increase-skip", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-angle-increase-skip", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Increase Angle More", NULL, NULL,
     GIMP_ACTION_SELECT_SKIP_NEXT, FALSE,
     NULL },
-  { "tools-angle-decrease-percent", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-angle-decrease-percent", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Decrease Angle Relative", NULL, NULL,
     GIMP_ACTION_SELECT_PERCENT_PREVIOUS, FALSE,
     NULL },
-  { "tools-angle-increase-percent", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-angle-increase-percent", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Increase Angle Relative", NULL, NULL,
     GIMP_ACTION_SELECT_PERCENT_NEXT, FALSE,
     NULL },
@@ -438,43 +436,43 @@ static const GimpEnumActionEntry tools_angle_actions[] =
 
 static const GimpEnumActionEntry tools_spacing_actions[] =
 {
-  { "tools-spacing-set", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-spacing-set", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Set Spacing", NULL, NULL,
     GIMP_ACTION_SELECT_SET, TRUE,
     NULL },
-  { "tools-spacing-set-to-default", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-spacing-set-to-default", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Set Spacing To Default Value", NULL, NULL,
     GIMP_ACTION_SELECT_SET_TO_DEFAULT, FALSE,
     NULL },
-  { "tools-spacing-minimum", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-spacing-minimum", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Minimize Spacing", NULL, NULL,
     GIMP_ACTION_SELECT_FIRST, FALSE,
     NULL },
-  { "tools-spacing-maximum", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-spacing-maximum", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Maximize Spacing", NULL, NULL,
     GIMP_ACTION_SELECT_LAST, FALSE,
     NULL },
-  { "tools-spacing-decrease", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-spacing-decrease", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Decrease Spacing", NULL, NULL,
     GIMP_ACTION_SELECT_PREVIOUS, FALSE,
     NULL },
-  { "tools-spacing-increase", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-spacing-increase", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Increase Spacing", NULL, NULL,
     GIMP_ACTION_SELECT_NEXT, FALSE,
     NULL },
-  { "tools-spacing-decrease-skip", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-spacing-decrease-skip", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Decrease Spacing More", NULL, NULL,
     GIMP_ACTION_SELECT_SKIP_PREVIOUS, FALSE,
     NULL },
-  { "tools-spacing-increase-skip", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-spacing-increase-skip", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Increase Spacing More", NULL, NULL,
     GIMP_ACTION_SELECT_SKIP_NEXT, FALSE,
     NULL },
-  { "tools-spacing-decrease-percent", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-spacing-decrease-percent", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Decrease Spacing Relative", NULL, NULL,
     GIMP_ACTION_SELECT_PERCENT_PREVIOUS, FALSE,
     NULL },
-  { "tools-spacing-increase-percent", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-spacing-increase-percent", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Increase Spacing Relative", NULL, NULL,
     GIMP_ACTION_SELECT_PERCENT_NEXT, FALSE,
     NULL },
@@ -482,43 +480,43 @@ static const GimpEnumActionEntry tools_spacing_actions[] =
 
 static const GimpEnumActionEntry tools_hardness_actions[] =
 {
-  { "tools-hardness-set", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-hardness-set", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Set Hardness", NULL, NULL,
     GIMP_ACTION_SELECT_SET, TRUE,
     NULL },
-  { "tools-hardness-set-to-default", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-hardness-set-to-default", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Set Hardness To Default Value", NULL, NULL,
     GIMP_ACTION_SELECT_SET_TO_DEFAULT, FALSE,
     NULL },
-  { "tools-hardness-minimum", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-hardness-minimum", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Minimize Hardness", NULL, NULL,
     GIMP_ACTION_SELECT_FIRST, FALSE,
     NULL },
-  { "tools-hardness-maximum", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-hardness-maximum", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Maximize Hardness", NULL, NULL,
     GIMP_ACTION_SELECT_LAST, FALSE,
     NULL },
-  { "tools-hardness-decrease", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-hardness-decrease", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Decrease Hardness", NULL, NULL,
     GIMP_ACTION_SELECT_PREVIOUS, FALSE,
     NULL },
-  { "tools-hardness-increase", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-hardness-increase", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Increase Hardness", NULL, NULL,
     GIMP_ACTION_SELECT_NEXT, FALSE,
     NULL },
-  { "tools-hardness-decrease-skip", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-hardness-decrease-skip", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Decrease Hardness More", NULL, NULL,
     GIMP_ACTION_SELECT_SKIP_PREVIOUS, FALSE,
     NULL },
-  { "tools-hardness-increase-skip", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-hardness-increase-skip", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Increase Hardness More", NULL, NULL,
     GIMP_ACTION_SELECT_SKIP_NEXT, FALSE,
     NULL },
-  { "tools-hardness-decrease-percent", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-hardness-decrease-percent", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Decrease Hardness Relative", NULL, NULL,
     GIMP_ACTION_SELECT_PERCENT_PREVIOUS, FALSE,
     NULL },
-  { "tools-hardness-increase-percent", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-hardness-increase-percent", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Increase Hardness Relative", NULL, NULL,
     GIMP_ACTION_SELECT_PERCENT_NEXT, FALSE,
     NULL },
@@ -526,43 +524,43 @@ static const GimpEnumActionEntry tools_hardness_actions[] =
 
 static const GimpEnumActionEntry tools_force_actions[] =
 {
-  { "tools-force-set", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-force-set", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Set Force", NULL, NULL,
     GIMP_ACTION_SELECT_SET, TRUE,
     NULL },
-  { "tools-force-set-to-default", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-force-set-to-default", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Set Force To Default Value", NULL, NULL,
     GIMP_ACTION_SELECT_SET_TO_DEFAULT, FALSE,
     NULL },
-  { "tools-force-minimum", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-force-minimum", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Minimize Force", NULL, NULL,
     GIMP_ACTION_SELECT_FIRST, FALSE,
     NULL },
-  { "tools-force-maximum", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-force-maximum", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Maximize Force", NULL, NULL,
     GIMP_ACTION_SELECT_LAST, FALSE,
     NULL },
-  { "tools-force-decrease", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-force-decrease", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Decrease Force", NULL, NULL,
     GIMP_ACTION_SELECT_PREVIOUS, FALSE,
     NULL },
-  { "tools-force-increase", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-force-increase", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Increase Force", NULL, NULL,
     GIMP_ACTION_SELECT_NEXT, FALSE,
     NULL },
-  { "tools-force-decrease-skip", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-force-decrease-skip", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Decrease Force More", NULL, NULL,
     GIMP_ACTION_SELECT_SKIP_PREVIOUS, FALSE,
     NULL },
-  { "tools-force-increase-skip", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-force-increase-skip", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Increase Force More", NULL, NULL,
     GIMP_ACTION_SELECT_SKIP_NEXT, FALSE,
     NULL },
-  { "tools-force-decrease-percent", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-force-decrease-percent", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Decrease Force Relative", NULL, NULL,
     GIMP_ACTION_SELECT_PERCENT_PREVIOUS, FALSE,
     NULL },
-  { "tools-force-increase-percent", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-force-increase-percent", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Increase Force Relative", NULL, NULL,
     GIMP_ACTION_SELECT_PERCENT_NEXT, FALSE,
     NULL },
@@ -570,23 +568,23 @@ static const GimpEnumActionEntry tools_force_actions[] =
 
 static const GimpEnumActionEntry tools_object_1_actions[] =
 {
-  { "tools-object-1-set", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-object-1-set", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Select Object 1 by Index", NULL, NULL,
     GIMP_ACTION_SELECT_SET, TRUE,
     NULL },
-  { "tools-object-1-first", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-object-1-first", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "First Object 1", NULL, NULL,
     GIMP_ACTION_SELECT_FIRST, FALSE,
     NULL },
-  { "tools-object-1-last", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-object-1-last", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Last Object 1", NULL, NULL,
     GIMP_ACTION_SELECT_LAST, FALSE,
     NULL },
-  { "tools-object-1-previous", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-object-1-previous", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Previous Object 1", NULL, NULL,
     GIMP_ACTION_SELECT_PREVIOUS, FALSE,
     NULL },
-  { "tools-object-1-next", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-object-1-next", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Next Object 1", NULL, NULL,
     GIMP_ACTION_SELECT_NEXT, FALSE,
     NULL }
@@ -594,23 +592,23 @@ static const GimpEnumActionEntry tools_object_1_actions[] =
 
 static const GimpEnumActionEntry tools_object_2_actions[] =
 {
-  { "tools-object-2-set", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-object-2-set", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Select Object 2 by Index", NULL, NULL,
     GIMP_ACTION_SELECT_SET, TRUE,
     NULL },
-  { "tools-object-2-first", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-object-2-first", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "First Object 2", NULL, NULL,
     GIMP_ACTION_SELECT_FIRST, FALSE,
     NULL },
-  { "tools-object-2-last", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-object-2-last", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Last Object 2", NULL, NULL,
     GIMP_ACTION_SELECT_LAST, FALSE,
     NULL },
-  { "tools-object-2-previous", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-object-2-previous", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Previous Object 2", NULL, NULL,
     GIMP_ACTION_SELECT_PREVIOUS, FALSE,
     NULL },
-  { "tools-object-2-next", GIMP_STOCK_TOOL_OPTIONS,
+  { "tools-object-2-next", GIMP_ICON_DIALOG_TOOL_OPTIONS,
     "Next Object 2", NULL, NULL,
     GIMP_ACTION_SELECT_NEXT, FALSE,
     NULL }
