@@ -53,22 +53,20 @@ struct _GimpDrawableClass
   void          (* alpha_changed)         (GimpDrawable         *drawable);
 
   /*  virtual functions  */
-  gint64        (* estimate_memsize)      (const GimpDrawable   *drawable,
+  gint64        (* estimate_memsize)      (GimpDrawable         *drawable,
                                            GimpComponentType     component_type,
                                            gint                  width,
                                            gint                  height);
   void          (* invalidate_boundary)   (GimpDrawable         *drawable);
-  void          (* get_active_components) (const GimpDrawable   *drawable,
+  void          (* get_active_components) (GimpDrawable         *drawable,
                                            gboolean             *active);
-  GimpComponentMask (* get_active_mask)   (const GimpDrawable   *drawable);
+  GimpComponentMask (* get_active_mask)   (GimpDrawable         *drawable);
   void          (* convert_type)          (GimpDrawable         *drawable,
                                            GimpImage            *dest_image,
                                            const Babl           *new_format,
-                                           GimpImageBaseType     new_base_type,
-                                           GimpPrecision         new_precision,
-                                           gint                  layer_dither_type,
-                                           gint                  mask_dither_type,
-                                           gboolean              convert_profile,
+                                           GimpColorProfile     *dest_profile,
+                                           GeglDitherMethod      layer_dither_type,
+                                           GeglDitherMethod      mask_dither_type,
                                            gboolean              push_undo,
                                            GimpProgress         *progress);
   void          (* apply_buffer)          (GimpDrawable         *drawable,
@@ -77,7 +75,10 @@ struct _GimpDrawableClass
                                            gboolean              push_undo,
                                            const gchar          *undo_desc,
                                            gdouble               opacity,
-                                           GimpLayerModeEffects  mode,
+                                           GimpLayerMode         mode,
+                                           GimpLayerColorSpace   blend_space,
+                                           GimpLayerColorSpace   composite_space,
+                                           GimpLayerCompositeMode composite_mode,
                                            GeglBuffer           *base_buffer,
                                            gint                  base_x,
                                            gint                  base_y);
@@ -123,7 +124,7 @@ GimpDrawable  * gimp_drawable_new                (GType               type,
                                                   gint                height,
                                                   const Babl         *format);
 
-gint64          gimp_drawable_estimate_memsize   (const GimpDrawable *drawable,
+gint64          gimp_drawable_estimate_memsize   (GimpDrawable       *drawable,
                                                   GimpComponentType   component_type,
                                                   gint                width,
                                                   gint                height);
@@ -136,17 +137,18 @@ void            gimp_drawable_update             (GimpDrawable       *drawable,
 void            gimp_drawable_alpha_changed      (GimpDrawable       *drawable);
 
 void           gimp_drawable_invalidate_boundary (GimpDrawable       *drawable);
-void         gimp_drawable_get_active_components (const GimpDrawable *drawable,
+void         gimp_drawable_get_active_components (GimpDrawable       *drawable,
                                                   gboolean           *active);
-GimpComponentMask gimp_drawable_get_active_mask  (const GimpDrawable *drawable);
+GimpComponentMask gimp_drawable_get_active_mask  (GimpDrawable       *drawable);
 
 void            gimp_drawable_convert_type       (GimpDrawable       *drawable,
                                                   GimpImage          *dest_image,
                                                   GimpImageBaseType   new_base_type,
                                                   GimpPrecision       new_precision,
-                                                  gint                layer_dither_type,
-                                                  gint                mask_dither_type,
-                                                  gboolean            convert_profile,
+                                                  gboolean            new_has_alpha,
+                                                  GimpColorProfile   *dest_profile,
+                                                  GeglDitherMethod    layer_dither_type,
+                                                  GeglDitherMethod    mask_dither_type,
                                                   gboolean            push_undo,
                                                   GimpProgress       *progress);
 
@@ -156,7 +158,10 @@ void            gimp_drawable_apply_buffer       (GimpDrawable        *drawable,
                                                   gboolean             push_undo,
                                                   const gchar         *undo_desc,
                                                   gdouble              opacity,
-                                                  GimpLayerModeEffects mode,
+                                                  GimpLayerMode        mode,
+                                                  GimpLayerColorSpace  blend_space,
+                                                  GimpLayerColorSpace  composite_space,
+                                                  GimpLayerCompositeMode composite_mode,
                                                   GeglBuffer          *base_buffer,
                                                   gint                 base_x,
                                                   gint                 base_y);
@@ -199,33 +204,25 @@ void            gimp_drawable_push_undo          (GimpDrawable       *drawable,
                                                   gint                width,
                                                   gint                height);
 
-const Babl    * gimp_drawable_get_format         (const GimpDrawable *drawable);
-const Babl    * gimp_drawable_get_format_with_alpha
-                                                 (const GimpDrawable *drawable);
-const Babl    * gimp_drawable_get_format_without_alpha
-                                                 (const GimpDrawable *drawable);
-gboolean        gimp_drawable_get_linear         (const GimpDrawable *drawable);
-gboolean        gimp_drawable_has_alpha          (const GimpDrawable *drawable);
-GimpImageBaseType gimp_drawable_get_base_type    (const GimpDrawable *drawable);
-GimpComponentType gimp_drawable_get_component_type(const GimpDrawable *drawable);
-GimpPrecision   gimp_drawable_get_precision      (const GimpDrawable *drawable);
-gboolean        gimp_drawable_is_rgb             (const GimpDrawable *drawable);
-gboolean        gimp_drawable_is_gray            (const GimpDrawable *drawable);
-gboolean        gimp_drawable_is_indexed         (const GimpDrawable *drawable);
+const Babl      * gimp_drawable_get_format           (GimpDrawable    *drawable);
+const Babl      * gimp_drawable_get_format_with_alpha(GimpDrawable    *drawable);
+const Babl      * gimp_drawable_get_format_without_alpha
+                                                     (GimpDrawable    *drawable);
+gboolean          gimp_drawable_get_linear           (GimpDrawable    *drawable);
+gboolean          gimp_drawable_has_alpha            (GimpDrawable    *drawable);
+GimpImageBaseType gimp_drawable_get_base_type        (GimpDrawable    *drawable);
+GimpComponentType gimp_drawable_get_component_type   (GimpDrawable    *drawable);
+GimpPrecision     gimp_drawable_get_precision        (GimpDrawable    *drawable);
+gboolean          gimp_drawable_is_rgb               (GimpDrawable    *drawable);
+gboolean          gimp_drawable_is_gray              (GimpDrawable    *drawable);
+gboolean          gimp_drawable_is_indexed           (GimpDrawable    *drawable);
 
-const Babl  * gimp_drawable_get_component_format (const GimpDrawable *drawable,
-                                                  GimpChannelType     channel);
-gint          gimp_drawable_get_component_index  (const GimpDrawable *drawable,
-                                                  GimpChannelType     channel);
+const Babl      * gimp_drawable_get_component_format (GimpDrawable    *drawable,
+                                                      GimpChannelType  channel);
+gint              gimp_drawable_get_component_index  (GimpDrawable    *drawable,
+                                                      GimpChannelType  channel);
 
-const guchar  * gimp_drawable_get_colormap       (const GimpDrawable *drawable);
-
-GimpLayer    * gimp_drawable_get_floating_sel    (const GimpDrawable *drawable);
-void           gimp_drawable_attach_floating_sel (GimpDrawable       *drawable,
-                                                  GimpLayer          *floating_sel);
-void           gimp_drawable_detach_floating_sel (GimpDrawable       *drawable);
-GimpFilter *
-           gimp_drawable_get_floating_sel_filter (GimpDrawable       *drawable);
+const guchar    * gimp_drawable_get_colormap         (GimpDrawable    *drawable);
 
 
 #endif /* __GIMP_DRAWABLE_H__ */
