@@ -20,8 +20,6 @@
 
 #include "config.h"
 
-#include <lcms2.h>
-
 #include <cairo.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gegl.h>
@@ -218,6 +216,16 @@ gimp_gegl_convolve (GeglBuffer          *src_buffer,
   g_free (src);
 }
 
+static inline gfloat
+odd_powf (gfloat x,
+          gfloat y)
+{
+  if (x >= 0.0f)
+    return  powf ( x, y);
+  else
+    return -powf (-x, y);
+}
+
 void
 gimp_gegl_dodgeburn (GeglBuffer          *src_buffer,
                      const GeglRectangle *src_rect,
@@ -278,9 +286,9 @@ gimp_gegl_dodgeburn (GeglBuffer          *src_buffer,
 
           while (count--)
             {
-              *dest++ = pow (*src++, factor);
-              *dest++ = pow (*src++, factor);
-              *dest++ = pow (*src++, factor);
+              *dest++ = odd_powf (*src++, factor);
+              *dest++ = odd_powf (*src++, factor);
+              *dest++ = odd_powf (*src++, factor);
 
               *dest++ = *src++;
             }
@@ -585,7 +593,7 @@ gimp_gegl_replace (GeglBuffer          *top_buffer,
 
                       new_val = bottom[b] + mask_val * (top[b] - bottom[b]);
 
-                      dest[b] = affect[b] ? MIN (new_val, 1.0) : bottom[b];
+                      dest[b] = affect[b] ? new_val : bottom[b];
                     }
                 }
 
@@ -612,7 +620,7 @@ gimp_gegl_replace (GeglBuffer          *top_buffer,
                 {
                   gfloat new_val = a_recip * (bottom[b] * s1_a + mask_val *
                                               (top[b] * s2_a - bottom[b] * s1_a));
-                  dest[b] = affect[b] ? MIN (new_val, 1.0) : bottom[b];
+                  dest[b] = affect[b] ? new_val : bottom[b];
                 }
             }
 
@@ -663,40 +671,6 @@ gimp_gegl_index_to_mask (GeglBuffer          *indexed_buffer,
     }
 }
 
-static gboolean
-gimp_color_profile_can_gegl_copy (GimpColorProfile *src_profile,
-                                  GimpColorProfile *dest_profile)
-{
-  static GimpColorProfile *srgb_profile        = NULL;
-  static GimpColorProfile *srgb_linear_profile = NULL;
-  static GimpColorProfile *gray_profile        = NULL;
-  static GimpColorProfile *gray_linear_profile = NULL;
-
-  if (gimp_color_profile_is_equal (src_profile, dest_profile))
-    return TRUE;
-
-  if (! srgb_profile)
-    {
-      srgb_profile        = gimp_color_profile_new_rgb_srgb ();
-      srgb_linear_profile = gimp_color_profile_new_rgb_srgb_linear ();
-      gray_profile        = gimp_color_profile_new_gray_srgb ();
-      gray_linear_profile = gimp_color_profile_new_gray_srgb_linear ();
-    }
-
-  if ((gimp_color_profile_is_equal (src_profile, srgb_profile)        ||
-       gimp_color_profile_is_equal (src_profile, srgb_linear_profile) ||
-       gimp_color_profile_is_equal (src_profile, gray_profile)        ||
-       gimp_color_profile_is_equal (src_profile, gray_linear_profile))
-      &&
-      (gimp_color_profile_is_equal (dest_profile, srgb_profile)        ||
-       gimp_color_profile_is_equal (dest_profile, srgb_linear_profile) ||
-       gimp_color_profile_is_equal (dest_profile, gray_profile)        ||
-       gimp_color_profile_is_equal (dest_profile, gray_linear_profile)))
-    return TRUE;
-
-  return FALSE;
-}
-
 void
 gimp_gegl_convert_color_profile (GeglBuffer               *src_buffer,
                                  const GeglRectangle      *src_rect,
@@ -708,51 +682,38 @@ gimp_gegl_convert_color_profile (GeglBuffer               *src_buffer,
                                  gboolean                  bpc,
                                  GimpProgress             *progress)
 {
-  const Babl       *src_format;
-  const Babl       *dest_format;
-  cmsHPROFILE       src_lcms;
-  cmsHPROFILE       dest_lcms;
-  cmsUInt32Number   lcms_src_format;
-  cmsUInt32Number   lcms_dest_format;
-  cmsUInt32Number   flags;
-  cmsHTRANSFORM     transform;
+  GimpColorTransform      *transform;
+  GimpColorTransformFlags  flags = 0;
+  const Babl              *src_format;
+  const Babl              *dest_format;
 
   src_format  = gegl_buffer_get_format (src_buffer);
   dest_format = gegl_buffer_get_format (dest_buffer);
 
-  if (gimp_color_profile_can_gegl_copy (src_profile, dest_profile))
-    {
-      gegl_buffer_copy (src_buffer,  src_rect, GEGL_ABYSS_NONE,
-                        dest_buffer, dest_rect);
-      return;
-    }
-
-  src_lcms  = gimp_color_profile_get_lcms_profile (src_profile);
-  dest_lcms = gimp_color_profile_get_lcms_profile (dest_profile);
-
-  src_format  = gimp_color_profile_get_format (src_format,  &lcms_src_format);
-  dest_format = gimp_color_profile_get_format (dest_format, &lcms_dest_format);
-
-  flags = cmsFLAGS_NOOPTIMIZE;
-
   if (bpc)
-    flags |= cmsFLAGS_BLACKPOINTCOMPENSATION;
+    flags |= GIMP_COLOR_TRANSFORM_FLAGS_BLACK_POINT_COMPENSATION;
 
-  transform = cmsCreateTransform (src_lcms,  lcms_src_format,
-                                  dest_lcms, lcms_dest_format,
-                                  intent, flags);
+  flags |= GIMP_COLOR_TRANSFORM_FLAGS_NOOPTIMIZE;
+
+  transform = gimp_color_transform_new (src_profile,  src_format,
+                                        dest_profile, dest_format,
+                                        intent, flags);
 
   if (transform)
     {
-      gimp_gegl_convert_color_transform (src_buffer,  src_rect,  src_format,
-                                         dest_buffer, dest_rect, dest_format,
-                                         transform, progress);
+      if (progress)
+        g_signal_connect_swapped (transform, "progress",
+                                  G_CALLBACK (gimp_progress_set_value),
+                                  progress);
 
-      cmsDeleteTransform (transform);
+      gimp_color_transform_process_buffer (transform,
+                                           src_buffer,  src_rect,
+                                           dest_buffer, dest_rect);
+
+      g_object_unref (transform);
     }
   else
     {
-      /* FIXME: no idea if this ever happens */
       gegl_buffer_copy (src_buffer,  src_rect, GEGL_ABYSS_NONE,
                         dest_buffer, dest_rect);
 
@@ -760,67 +721,3 @@ gimp_gegl_convert_color_profile (GeglBuffer               *src_buffer,
         gimp_progress_set_value (progress, 1.0);
     }
 }
-
-void
-gimp_gegl_convert_color_transform (GeglBuffer          *src_buffer,
-                                   const GeglRectangle *src_rect,
-                                   const Babl          *src_format,
-                                   GeglBuffer          *dest_buffer,
-                                   const GeglRectangle *dest_rect,
-                                   const Babl          *dest_format,
-                                   GimpColorTransform   transform,
-                                   GimpProgress        *progress)
-{
-  GeglBufferIterator *iter;
-  gboolean            has_alpha;
-  gint                total_pixels;
-  gint                done_pixels = 0;
-
-  if (src_rect)
-    {
-      total_pixels = src_rect->width * src_rect->height;
-    }
-  else
-    {
-      total_pixels = (gegl_buffer_get_width  (src_buffer) *
-                      gegl_buffer_get_height (src_buffer));
-    }
-
-  has_alpha = babl_format_has_alpha (dest_format);
-
-  /* make sure the alpha channel is copied too, lcms doesn't copy it */
-  if (has_alpha)
-    gegl_buffer_copy (src_buffer,  src_rect, GEGL_ABYSS_NONE,
-                      dest_buffer, dest_rect);
-
-  iter = gegl_buffer_iterator_new (src_buffer, src_rect, 0,
-                                   src_format,
-                                   GEGL_ACCESS_READ,
-                                   GEGL_ABYSS_NONE);
-
-  gegl_buffer_iterator_add (iter, dest_buffer, dest_rect, 0,
-                            dest_format,
-                            /* use READWRITE for alpha surfaces
-                             * because we must use the alpha channel
-                             * that is already copied, see above
-                             */
-                            has_alpha ?
-                            GEGL_ACCESS_READWRITE: GEGL_ACCESS_WRITE,
-                            GEGL_ABYSS_NONE);
-
-  while (gegl_buffer_iterator_next (iter))
-    {
-      cmsDoTransform (transform,
-                      iter->data[0], iter->data[1], iter->length);
-
-      done_pixels += iter->roi[0].width * iter->roi[0].height;
-
-      if (progress)
-        gimp_progress_set_value (progress,
-                                 (gdouble) done_pixels /
-                                 (gdouble) total_pixels);
-    }
-
-  if (progress)
-    gimp_progress_set_value (progress, 1.0);
-}
