@@ -78,9 +78,21 @@
 #include "session.h"
 #include "splash.h"
 #include "themes.h"
+
 #ifdef GDK_WINDOWING_QUARTZ
 #import <AppKit/AppKit.h>
 #include <gtkosxapplication.h>
+
+/* Forward declare since we are building against old SDKs. */
+#if !defined(MAC_OS_X_VERSION_10_12) || \
+    MAC_OS_X_VERSION_MIN_REQUIRED < MAC_OS_X_VERSION_10_12
+
+@interface NSWindow(ForwardDeclarations)
++ (void)setAllowsAutomaticWindowTabbing:(BOOL)allow;
+@end
+
+#endif
+
 #endif /* GDK_WINDOWING_QUARTZ */
 
 #include "gimp-intl.h"
@@ -123,7 +135,7 @@ static void       gui_tearoff_menus_notify      (GimpGuiConfig      *gui_config,
                                                  GParamSpec         *pspec,
                                                  GtkUIManager       *manager);
 
-static void       gui_global_buffer_changed     (Gimp               *gimp);
+static void       gui_clipboard_changed         (Gimp               *gimp);
 
 static void       gui_menu_show_tooltip         (GimpUIManager      *manager,
                                                  const gchar        *tooltip,
@@ -135,6 +147,17 @@ static void       gui_display_changed           (GimpContext        *context,
                                                  GimpDisplay        *display,
                                                  Gimp               *gimp);
 
+static void       gui_compare_accelerator       (gpointer            data,
+                                                 const gchar        *accel_path,
+                                                 guint               accel_key,
+                                                 GdkModifierType     accel_mods,
+                                                 gboolean            changed);
+static void      gui_check_unique_accelerator   (gpointer            data,
+                                                 const gchar        *accel_path,
+                                                 guint               accel_key,
+                                                 GdkModifierType     accel_mods,
+                                                 gboolean            changed);
+
 
 /*  private variables  */
 
@@ -165,13 +188,15 @@ gui_abort (const gchar *abort_message)
 
   dialog = gimp_dialog_new (_("GIMP Message"), "gimp-abort",
                             NULL, GTK_DIALOG_MODAL, NULL, NULL,
-                            GTK_STOCK_OK, GTK_RESPONSE_OK,
+
+                            _("_OK"), GTK_RESPONSE_OK,
+
                             NULL);
 
   gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 
   box = g_object_new (GIMP_TYPE_MESSAGE_BOX,
-                      "icon-name",    GIMP_STOCK_WILBER_EEK,
+                      "icon-name",    GIMP_ICON_WILBER_EEK,
                       "border-width", 12,
                       NULL);
 
@@ -242,6 +267,17 @@ gui_init (Gimp     *gimp,
   /*  disable automatic startup notification  */
   gtk_window_set_auto_startup_notification (FALSE);
 
+#ifdef GDK_WINDOWING_QUARTZ
+  /* Before the first window is created (typically the splash window),
+   * we need to disable automatic tabbing behavior introduced on Sierra.
+   * This is known to cause all kinds of weird issues (see for instance
+   * Bugzilla #776294) and needs proper GTK+ support if we would want to
+   * enable it.
+   */
+  if ([NSWindow respondsToSelector:@selector(setAllowsAutomaticWindowTabbing:)])
+    [NSWindow setAllowsAutomaticWindowTabbing:NO];
+#endif /* GDK_WINDOWING_QUARTZ */
+
   gimp_dnd_init (gimp);
 
   themes_init (gimp);
@@ -449,10 +485,13 @@ gui_restore_callback (Gimp               *gimp,
   dialogs_init (gimp, global_menu_factory);
 
   gimp_clipboard_init (gimp);
-  gimp_clipboard_set_buffer (gimp, gimp->global_buffer);
+  if (gimp_get_clipboard_image (gimp))
+    gimp_clipboard_set_image (gimp, gimp_get_clipboard_image (gimp));
+  else
+    gimp_clipboard_set_buffer (gimp, gimp_get_clipboard_buffer (gimp));
 
-  g_signal_connect (gimp, "buffer-changed",
-                    G_CALLBACK (gui_global_buffer_changed),
+  g_signal_connect (gimp, "clipboard-changed",
+                    G_CALLBACK (gui_clipboard_changed),
                     NULL);
 
   gimp_devices_init (gimp);
@@ -532,6 +571,10 @@ gui_restore_after_callback (Gimp               *gimp,
                                                     gui_config->tearoff_menus);
   gimp_ui_manager_update (image_ui_manager, gimp);
 
+  /* Check that every accelerator is unique. */
+  gtk_accel_map_foreach_unfiltered (NULL,
+                                    gui_check_unique_accelerator);
+
   gimp_action_history_init (gimp);
 
 #ifdef GDK_WINDOWING_QUARTZ
@@ -668,9 +711,6 @@ gui_exit_callback (Gimp     *gimp,
   if (gui_config->save_session_info)
     session_save (gimp, FALSE);
 
-  if (gui_config->save_accels)
-    menus_save (gimp, FALSE);
-
   if (gui_config->save_device_status)
     gimp_devices_save (gimp, FALSE);
 
@@ -683,6 +723,9 @@ gui_exit_callback (Gimp     *gimp,
 
   gimp_displays_delete (gimp);
 
+  if (gui_config->save_accels)
+    menus_save (gimp, FALSE);
+
   gimp_tools_save (gimp, gui_config->save_tool_options, FALSE);
   gimp_tools_exit (gimp);
 
@@ -720,7 +763,7 @@ gui_exit_after_callback (Gimp     *gimp,
    *  a whole lot of code paths. See bug #731389.
    */
   g_signal_handlers_disconnect_by_func (gimp,
-                                        G_CALLBACK (gui_global_buffer_changed),
+                                        G_CALLBACK (gui_clipboard_changed),
                                         NULL);
   gimp_clipboard_exit (gimp);
 
@@ -784,9 +827,12 @@ gui_tearoff_menus_notify (GimpGuiConfig *gui_config,
 }
 
 static void
-gui_global_buffer_changed (Gimp *gimp)
+gui_clipboard_changed (Gimp *gimp)
 {
-  gimp_clipboard_set_buffer (gimp, gimp->global_buffer);
+  if (gimp_get_clipboard_image (gimp))
+    gimp_clipboard_set_image (gimp, gimp_get_clipboard_image (gimp));
+  else
+    gimp_clipboard_set_buffer (gimp, gimp_get_clipboard_buffer (gimp));
 }
 
 static void
@@ -860,3 +906,50 @@ gui_display_changed (GimpContext *context,
 
   gimp_ui_manager_update (image_ui_manager, display);
 }
+
+typedef struct
+{
+  const gchar     *path;
+  guint            key;
+  GdkModifierType  mods;
+}
+accelData;
+
+static void
+gui_compare_accelerator (gpointer         data,
+                         const gchar     *accel_path,
+                         guint            accel_key,
+                         GdkModifierType  accel_mods,
+                         gboolean         changed)
+{
+  accelData *accel = data;
+
+  if (accel->key == accel_key && accel->mods == accel_mods &&
+      g_strcmp0 (accel->path, accel_path))
+    {
+      g_warning ("Actions \"%s\" and \"%s\" use the same accelerator.\n"
+                 "Disable the accelerator on \"%s\".",
+                 accel->path, accel_path, accel_path);
+      gtk_accel_map_change_entry (accel_path, 0, 0, FALSE);
+    }
+}
+
+static void
+gui_check_unique_accelerator (gpointer         data,
+                              const gchar     *accel_path,
+                              guint            accel_key,
+                              GdkModifierType  accel_mods,
+                              gboolean         changed)
+{
+  if (gtk_accelerator_valid (accel_key, accel_mods))
+    {
+      accelData accel;
+
+      accel.path = accel_path;
+      accel.key  = accel_key;
+      accel.mods = accel_mods;
+
+      gtk_accel_map_foreach_unfiltered (&accel,
+                                        gui_compare_accelerator);
+    }
+}
