@@ -66,6 +66,17 @@
 #define PARTIAL_HANDLE_THRESHOLD_SQ (FULL_HANDLE_THRESHOLD_SQ * 5)
 
 
+typedef struct _BlendInfo BlendInfo;
+
+struct _BlendInfo
+{
+  gdouble start_x;
+  gdouble start_y;
+  gdouble end_x;
+  gdouble end_y;
+};
+
+
 /*  local function prototypes  */
 
 static void   gimp_blend_tool_dispose             (GObject               *object);
@@ -98,7 +109,7 @@ static void   gimp_blend_tool_motion              (GimpTool              *tool,
                                                    guint32                time,
                                                    GdkModifierType        state,
                                                    GimpDisplay           *display);
-static void   gimp_blend_tool_point_motion        (GimpBlendTool         *blend_tool,
+static gboolean gimp_blend_tool_point_motion      (GimpBlendTool         *blend_tool,
                                                    gboolean               constrain_angle);
 static gboolean gimp_blend_tool_key_press         (GimpTool              *tool,
                                                    GdkEventKey           *kevent,
@@ -112,6 +123,14 @@ static void   gimp_blend_tool_cursor_update       (GimpTool              *tool,
                                                    const GimpCoords      *coords,
                                                    GdkModifierType        state,
                                                    GimpDisplay           *display);
+static const gchar * gimp_blend_tool_get_undo_desc(GimpTool              *tool,
+                                                   GimpDisplay           *display);
+static const gchar * gimp_blend_tool_get_redo_desc(GimpTool              *tool,
+                                                   GimpDisplay           *display);
+static gboolean  gimp_blend_tool_undo             (GimpTool              *tool,
+                                                   GimpDisplay           *display);
+static gboolean  gimp_blend_tool_redo             (GimpTool              *tool,
+                                                   GimpDisplay           *display);
 static void   gimp_blend_tool_options_notify      (GimpTool              *tool,
                                                    GimpToolOptions       *options,
                                                    const GParamSpec      *pspec);
@@ -148,6 +167,12 @@ static void   gimp_blend_tool_create_filter       (GimpBlendTool         *blend_
 static void   gimp_blend_tool_filter_flush        (GimpDrawableFilter    *filter,
                                                    GimpTool              *tool);
 
+static BlendInfo * blend_info_new  (gdouble    start_x,
+                                    gdouble    start_y,
+                                    gdouble    end_x,
+                                    gdouble    end_y);
+static void        blend_info_free (BlendInfo *info);
+
 
 G_DEFINE_TYPE (GimpBlendTool, gimp_blend_tool, GIMP_TYPE_DRAW_TOOL)
 
@@ -193,6 +218,10 @@ gimp_blend_tool_class_init (GimpBlendToolClass *klass)
   tool_class->key_press           = gimp_blend_tool_key_press;
   tool_class->active_modifier_key = gimp_blend_tool_active_modifier_key;
   tool_class->cursor_update       = gimp_blend_tool_cursor_update;
+  tool_class->get_undo_desc       = gimp_blend_tool_get_undo_desc;
+  tool_class->get_redo_desc       = gimp_blend_tool_get_redo_desc;
+  tool_class->undo                = gimp_blend_tool_undo;
+  tool_class->redo                = gimp_blend_tool_redo;
   tool_class->options_notify      = gimp_blend_tool_options_notify;
 
   draw_tool_class->draw           = gimp_blend_tool_draw;
@@ -355,13 +384,37 @@ gimp_blend_tool_button_press (GimpTool            *tool,
       blend_tool->grabbed_point = POINT_BOTH;
     }
 
+  if ((blend_tool->grabbed_point == POINT_START ||
+       blend_tool->grabbed_point == POINT_END   ||
+       blend_tool->grabbed_point == POINT_BOTH) &&
+      gimp_draw_tool_is_active (GIMP_DRAW_TOOL (tool)))
+    {
+      blend_tool->undo_stack =
+        g_list_prepend (blend_tool->undo_stack,
+                        blend_info_new (blend_tool->start_x,
+                                        blend_tool->start_y,
+                                        blend_tool->end_x,
+                                        blend_tool->end_y));
+
+      if (blend_tool->redo_stack)
+        {
+          g_list_free_full (blend_tool->redo_stack,
+                            (GDestroyNotify) blend_info_free);
+          blend_tool->redo_stack = NULL;
+        }
+
+      /*  update the undo actions / menu items  */
+      gimp_image_flush (gimp_display_get_image (display));
+    }
+
   gimp_blend_tool_point_motion (blend_tool,
                                 state & gimp_get_constrain_behavior_mask ());
 
   tool->display = display;
   gimp_blend_tool_update_items (blend_tool);
 
-  if (blend_tool->grabbed_point != POINT_FILL_MODE &&
+  if (blend_tool->grabbed_point != POINT_NONE      &&
+      blend_tool->grabbed_point != POINT_FILL_MODE &&
       blend_tool->grabbed_point != POINT_INIT_MODE)
     {
       gimp_blend_tool_update_graph (blend_tool);
@@ -381,7 +434,7 @@ gimp_blend_tool_button_release (GimpTool              *tool,
                                 GimpButtonReleaseType  release_type,
                                 GimpDisplay           *display)
 {
-  GimpBlendTool    *blend_tool    = GIMP_BLEND_TOOL (tool);
+  GimpBlendTool *blend_tool = GIMP_BLEND_TOOL (tool);
 
   gimp_tool_pop_status (tool, display);
   /* XXX: Push a useful status message */
@@ -394,7 +447,16 @@ gimp_blend_tool_button_release (GimpTool              *tool,
       break;
 
     case GIMP_BUTTON_RELEASE_CANCEL:
-      /* XXX: handle cancel properly */
+      if ((blend_tool->grabbed_point == POINT_START ||
+           blend_tool->grabbed_point == POINT_END   ||
+           blend_tool->grabbed_point == POINT_BOTH) &&
+          blend_tool->undo_stack)
+        {
+          gimp_blend_tool_undo (tool, display);
+          blend_info_free (blend_tool->redo_stack->data);
+          blend_tool->redo_stack = g_list_remove (blend_tool->redo_stack,
+                                                  blend_tool->redo_stack->data);
+        }
       break;
 
     case GIMP_BUTTON_RELEASE_CLICK:
@@ -455,23 +517,28 @@ gimp_blend_tool_motion (GimpTool         *tool,
 
       blend_tool->end_x -= dx;
       blend_tool->end_y -= dy;
+
+      gimp_blend_tool_update_graph (blend_tool);
+      gimp_drawable_filter_apply (blend_tool->filter, NULL);
     }
   else
     {
-      gimp_blend_tool_point_motion (blend_tool,
-                                    state & gimp_get_constrain_behavior_mask ());
+      gboolean constrain = (state & gimp_get_constrain_behavior_mask ()) != 0;
+
+      if (gimp_blend_tool_point_motion (blend_tool, constrain))
+        {
+          gimp_blend_tool_update_graph (blend_tool);
+          gimp_drawable_filter_apply (blend_tool->filter, NULL);
+        }
     }
 
   gimp_tool_pop_status (tool, display);
   gimp_blend_tool_push_status (blend_tool, state, display);
 
   gimp_blend_tool_update_items (blend_tool);
-
-  gimp_blend_tool_update_graph (blend_tool);
-  gimp_drawable_filter_apply (blend_tool->filter, NULL);
 }
 
-static void
+static gboolean
 gimp_blend_tool_point_motion (GimpBlendTool *blend_tool,
                               gboolean       constrain_angle)
 {
@@ -488,7 +555,7 @@ gimp_blend_tool_point_motion (GimpBlendTool *blend_tool,
                                &blend_tool->start_x, &blend_tool->start_y,
                                GIMP_CONSTRAIN_LINE_15_DEGREES);
         }
-      break;
+      return TRUE;
 
     case POINT_END:
       blend_tool->end_x = blend_tool->mouse_x;
@@ -500,11 +567,13 @@ gimp_blend_tool_point_motion (GimpBlendTool *blend_tool,
                                &blend_tool->end_x, &blend_tool->end_y,
                                GIMP_CONSTRAIN_LINE_15_DEGREES);
         }
-      break;
+      return TRUE;
 
     default:
       break;
     }
+
+  return FALSE;
 }
 
 static gboolean
@@ -594,6 +663,98 @@ gimp_blend_tool_cursor_update (GimpTool         *tool,
   GIMP_TOOL_CLASS (parent_class)->cursor_update (tool, coords, state, display);
 }
 
+static const gchar *
+gimp_blend_tool_get_undo_desc (GimpTool    *tool,
+                               GimpDisplay *display)
+{
+  GimpBlendTool *blend_tool = GIMP_BLEND_TOOL (tool);
+  GimpDrawTool  *draw_tool  = GIMP_DRAW_TOOL (tool);
+
+  if (display != draw_tool->display || ! blend_tool->undo_stack)
+    return NULL;
+
+  return _("Blend Step");
+}
+
+static const gchar *
+gimp_blend_tool_get_redo_desc (GimpTool    *tool,
+                               GimpDisplay *display)
+{
+  GimpBlendTool *blend_tool = GIMP_BLEND_TOOL (tool);
+  GimpDrawTool  *draw_tool  = GIMP_DRAW_TOOL (tool);
+
+  if (display != draw_tool->display || ! blend_tool->redo_stack)
+    return NULL;
+
+  return _("Blend Step");
+}
+
+static gboolean
+gimp_blend_tool_undo (GimpTool    *tool,
+                      GimpDisplay *display)
+{
+  GimpBlendTool *blend_tool = GIMP_BLEND_TOOL (tool);
+  BlendInfo     *info;
+
+  if (! gimp_blend_tool_get_undo_desc (tool, display))
+    return FALSE;
+
+  info = blend_info_new (blend_tool->start_x,
+                         blend_tool->start_y,
+                         blend_tool->end_x,
+                         blend_tool->end_y);
+  blend_tool->redo_stack = g_list_prepend (blend_tool->redo_stack, info);
+
+  info = blend_tool->undo_stack->data;
+
+  blend_tool->start_x = info->start_x;
+  blend_tool->start_y = info->start_y;
+  blend_tool->end_x   = info->end_x;
+  blend_tool->end_y   = info->end_y;
+
+  blend_tool->undo_stack = g_list_remove (blend_tool->undo_stack, info);
+  blend_info_free (info);
+
+  gimp_blend_tool_update_graph (blend_tool);
+  gimp_drawable_filter_apply (blend_tool->filter, NULL);
+  gimp_blend_tool_update_items (blend_tool);
+
+  return TRUE;
+}
+
+static gboolean
+gimp_blend_tool_redo (GimpTool    *tool,
+                      GimpDisplay *display)
+{
+  GimpBlendTool *blend_tool = GIMP_BLEND_TOOL (tool);
+  BlendInfo     *info;
+
+  if (! gimp_blend_tool_get_redo_desc (tool, display))
+    return FALSE;
+
+  info = blend_info_new (blend_tool->start_x,
+                         blend_tool->start_y,
+                         blend_tool->end_x,
+                         blend_tool->end_y);
+  blend_tool->undo_stack = g_list_prepend (blend_tool->undo_stack, info);
+
+  info = blend_tool->redo_stack->data;
+
+  blend_tool->start_x = info->start_x;
+  blend_tool->start_y = info->start_y;
+  blend_tool->end_x   = info->end_x;
+  blend_tool->end_y   = info->end_y;
+
+  blend_tool->redo_stack = g_list_remove (blend_tool->redo_stack, info);
+  blend_info_free (info);
+
+  gimp_blend_tool_update_graph (blend_tool);
+  gimp_drawable_filter_apply (blend_tool->filter, NULL);
+  gimp_blend_tool_update_items (blend_tool);
+
+  return TRUE;
+}
+
 static void
 gimp_blend_tool_options_notify (GimpTool         *tool,
                                 GimpToolOptions  *options,
@@ -932,6 +1093,20 @@ gimp_blend_tool_halt (GimpBlendTool *blend_tool)
       gimp_image_flush (gimp_display_get_image (tool->display));
     }
 
+  if (blend_tool->undo_stack)
+    {
+      g_list_free_full (blend_tool->undo_stack,
+                        (GDestroyNotify) blend_info_free);
+      blend_tool->undo_stack = NULL;
+    }
+
+  if (blend_tool->redo_stack)
+    {
+      g_list_free_full (blend_tool->redo_stack,
+                        (GDestroyNotify) blend_info_free);
+      blend_tool->redo_stack = NULL;
+    }
+
   tool->display  = NULL;
   tool->drawable = NULL;
 
@@ -1225,3 +1400,25 @@ gimp_blend_tool_filter_flush (GimpDrawableFilter *filter,
 
   gimp_projection_flush (gimp_image_get_projection (image));
 }
+
+static BlendInfo *
+blend_info_new (gdouble start_x,
+                gdouble start_y,
+                gdouble end_x,
+                gdouble end_y)
+{
+  BlendInfo *info = g_slice_new0 (BlendInfo);
+
+  info->start_x = start_x;
+  info->start_y = start_y;
+  info->end_x   = end_x;
+  info->end_y   = end_y;
+
+  return info;
+}
+
+static void
+blend_info_free (BlendInfo *info)
+{
+  g_slice_free (BlendInfo, info);
+}
