@@ -56,7 +56,11 @@ static gchar    * gimp_color_balance_tool_get_operation (GimpFilterTool  *filter
                                                          gchar          **description,
                                                          gchar          **undo_desc,
                                                          gchar          **icon_name,
-                                                         gchar          **help_id);
+                                                         gchar          **help_id,
+                                                         gboolean        *has_settings,
+                                                         gchar          **settings_folder,
+                                                         gchar          **import_dialog_title,
+                                                         gchar          **export_dialog_title);
 static void       gimp_color_balance_tool_dialog        (GimpFilterTool  *filter_tool);
 static void       gimp_color_balance_tool_reset         (GimpFilterTool  *filter_tool);
 
@@ -92,15 +96,11 @@ gimp_color_balance_tool_class_init (GimpColorBalanceToolClass *klass)
   GimpToolClass       *tool_class        = GIMP_TOOL_CLASS (klass);
   GimpFilterToolClass *filter_tool_class = GIMP_FILTER_TOOL_CLASS (klass);
 
-  tool_class->initialize                 = gimp_color_balance_tool_initialize;
+  tool_class->initialize           = gimp_color_balance_tool_initialize;
 
-  filter_tool_class->settings_name       = "color-balance";
-  filter_tool_class->import_dialog_title = _("Import Color Balance Settings");
-  filter_tool_class->export_dialog_title = _("Export Color Balance Settings");
-
-  filter_tool_class->get_operation       = gimp_color_balance_tool_get_operation;
-  filter_tool_class->dialog              = gimp_color_balance_tool_dialog;
-  filter_tool_class->reset               = gimp_color_balance_tool_reset;
+  filter_tool_class->get_operation = gimp_color_balance_tool_get_operation;
+  filter_tool_class->dialog        = gimp_color_balance_tool_dialog;
+  filter_tool_class->reset         = gimp_color_balance_tool_reset;
 }
 
 static void
@@ -135,9 +135,17 @@ gimp_color_balance_tool_get_operation (GimpFilterTool  *filter_tool,
                                        gchar          **description,
                                        gchar          **undo_desc,
                                        gchar          **icon_name,
-                                       gchar          **help_id)
+                                       gchar          **help_id,
+                                       gboolean        *has_settings,
+                                       gchar          **settings_folder,
+                                       gchar          **import_dialog_title,
+                                       gchar          **export_dialog_title)
 {
-  *description = g_strdup (_("Adjust Color Balance"));
+  *description         = g_strdup (_("Adjust Color Balance"));
+  *has_settings        = TRUE;
+  *settings_folder     = g_strdup ("color-balance");
+  *import_dialog_title = g_strdup (_("Import Color Balance Settings"));
+  *export_dialog_title = g_strdup (_("Export Color Balance Settings"));
 
   return g_strdup ("gimp:color-balance");
 }
