@@ -184,7 +184,6 @@
 #define GIMP_HELP_LAYER_RAISE_TO_TOP              "gimp-layer-raise-to-top"
 #define GIMP_HELP_LAYER_LOWER                     "gimp-layer-lower"
 #define GIMP_HELP_LAYER_LOWER_TO_BOTTOM           "gimp-layer-lower-to-bottom"
-#define GIMP_HELP_LAYER_INVERT                    "gimp-layer-invert"
 #define GIMP_HELP_LAYER_WHITE_BALANCE             "gimp-layer-white-balance"
 #define GIMP_HELP_LAYER_EQUALIZE                  "gimp-layer-equalize"
 #define GIMP_HELP_LAYER_DILATE                    "gimp-layer-dilate"
@@ -371,7 +370,11 @@
 #define GIMP_HELP_FILTER_GEGL_GRAPH               "gimp-filter-gegl"
 #define GIMP_HELP_FILTER_GAUSSIAN_GRID            "gimp-filter-grid"
 #define GIMP_HELP_FILTER_HIGH_PASS                "gimp-filter-high-pass"
+#define GIMP_HELP_FILTER_HUE_CHROMA               "gimp-filter-hue-chroma"
 #define GIMP_HELP_FILTER_ILLUSION                 "gimp-filter-illusion"
+#define GIMP_HELP_FILTER_INVERT_LINEAR            "gimp-filter-invert-linear"
+#define GIMP_HELP_FILTER_INVERT_PERCEPTUAL        "gimp-filter-invert-perceptual"
+#define GIMP_HELP_FILTER_INVERT_VALUE             "gimp-filter-invert-value"
 #define GIMP_HELP_FILTER_IMAGE_GRADIENT           "gimp-filter-image-gradient"
 #define GIMP_HELP_FILTER_KALEIDOSCOPE             "gimp-filter-kaleidoscope"
 #define GIMP_HELP_FILTER_LENS_DISTORTION          "gimp-filter-lens-distortion"
