@@ -214,7 +214,7 @@ gimp_overlay_dialog_constructed (GObject *object)
   gtk_box_pack_end (GTK_BOX (dialog->header), button, FALSE, FALSE, 0);
   gtk_widget_show (button);
 
-  image = gtk_image_new_from_icon_name (GIMP_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
+  image = gtk_image_new_from_icon_name (GIMP_ICON_CLOSE, GTK_ICON_SIZE_MENU);
   gtk_image_set_pixel_size (GTK_IMAGE (image), 12);
   gtk_container_add (GTK_CONTAINER (button), image);
   gtk_widget_show (image);
@@ -233,7 +233,7 @@ gimp_overlay_dialog_constructed (GObject *object)
   gimp_help_set_help_data (dialog->detach_button,
                            _("Detach dialog from canvas"), NULL);
 
-  image = gtk_image_new_from_icon_name (GIMP_STOCK_MENU_LEFT,
+  image = gtk_image_new_from_icon_name (GIMP_ICON_DETACH,
                                         GTK_ICON_SIZE_MENU);
   gtk_image_set_pixel_size (GTK_IMAGE (image), 12);
   gtk_container_add (GTK_CONTAINER (button), image);
@@ -520,7 +520,7 @@ gimp_overlay_dialog_response (GimpOverlayDialog *dialog,
   g_return_if_fail (GIMP_IS_OVERLAY_DIALOG (dialog));
 
   g_signal_emit (dialog, signals[RESPONSE], 0,
-		 response_id);
+                 response_id);
 }
 
 void
@@ -654,7 +654,7 @@ response_data_free (gpointer data)
 
 static ResponseData *
 get_response_data (GtkWidget *widget,
-		   gboolean   create)
+                   gboolean   create)
 {
   ResponseData *ad = g_object_get_data (G_OBJECT (widget),
                                         "gimp-overlay-dialog-response-data");
