@@ -53,7 +53,8 @@ enum
   PROP_0,
   PROP_ICON_NAME,
   PROP_STOCK_ID,
-  PROP_STOCK_SIZE
+  PROP_STOCK_SIZE,
+  PROP_OVERRIDE_BACKGROUND
 };
 
 
@@ -64,6 +65,8 @@ struct _GimpCellRendererTogglePrivate
   gchar       *icon_name;
   gchar       *stock_id;
   GtkIconSize  stock_size;
+  gboolean     override_background;
+
   GdkPixbuf   *pixbuf;
 };
 
@@ -161,6 +164,13 @@ gimp_cell_renderer_toggle_class_init (GimpCellRendererToggleClass *klass)
                                                      GIMP_PARAM_READWRITE |
                                                      G_PARAM_CONSTRUCT));
 
+  g_object_class_install_property (object_class, PROP_OVERRIDE_BACKGROUND,
+                                   g_param_spec_boolean ("override-background",
+                                                         NULL, NULL,
+                                                         FALSE,
+                                                         GIMP_PARAM_READWRITE |
+                                                         G_PARAM_CONSTRUCT));
+
   g_type_class_add_private (object_class, sizeof (GimpCellRendererTogglePrivate));
 }
 
@@ -217,6 +227,10 @@ gimp_cell_renderer_toggle_get_property (GObject    *object,
       g_value_set_int (value, priv->stock_size);
       break;
 
+    case PROP_OVERRIDE_BACKGROUND:
+      g_value_set_boolean (value, priv->override_background);
+      break;
+
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
       break;
@@ -249,6 +263,10 @@ gimp_cell_renderer_toggle_set_property (GObject      *object,
       priv->stock_size = g_value_get_int (value);
       break;
 
+    case PROP_OVERRIDE_BACKGROUND:
+      priv->override_background = g_value_get_boolean (value);
+      break;
+
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
       break;
@@ -364,6 +382,31 @@ gimp_cell_renderer_toggle_render (GtkCellRenderer      *cell,
       return;
     }
 
+  if (flags & GTK_CELL_RENDERER_SELECTED &&
+      priv->override_background)
+    {
+      gboolean background_set;
+
+      g_object_get (cell,
+                    "cell-background-set", &background_set,
+                    NULL);
+
+      if (background_set)
+        {
+          GdkRGBA *color;
+
+          g_object_get (cell,
+                        "cell-background-rgba", &color,
+                        NULL);
+
+          gdk_cairo_rectangle (cr, background_area);
+          gdk_cairo_set_source_rgba (cr, color);
+          cairo_fill (cr);
+
+          gdk_rgba_free (color);
+        }
+    }
+
   gimp_cell_renderer_toggle_get_size (cell, widget, cell_area,
                                       &toggle_rect.x,
                                       &toggle_rect.y,
