@@ -445,9 +445,24 @@ gimp_color_area_draw (GtkWidget *widget,
 
   cairo_set_source_surface (cr, buffer, 0.0, 0.0);
   cairo_surface_destroy (buffer);
-
   cairo_paint (cr);
 
+  if (priv->config &&
+      (priv->color.r < 0.0 || priv->color.r > 1.0 ||
+       priv->color.g < 0.0 || priv->color.g > 1.0 ||
+       priv->color.b < 0.0 || priv->color.b > 1.0))
+    {
+      gint side = MIN (priv->width, priv->height) * 2 / 3;
+
+      cairo_move_to (cr, priv->width, 0);
+      cairo_line_to (cr, priv->width - side, 0);
+      cairo_line_to (cr, priv->width, side);
+      cairo_line_to (cr, priv->width, 0);
+
+      gimp_cairo_set_source_rgb (cr, &priv->config->out_of_gamut_color);
+      cairo_fill (cr);
+    }
+
   if (priv->draw_border)
     {
       GdkRGBA color;
