@@ -140,7 +140,7 @@ gimp_color_display_class_init (GimpColorDisplayClass *klass)
 
   klass->name            = "Unnamed";
   klass->help_id         = NULL;
-  klass->icon_name       = GIMP_STOCK_DISPLAY_FILTER;
+  klass->icon_name       = GIMP_ICON_DISPLAY_FILTER;
 
   klass->clone           = NULL;
   klass->convert_buffer  = NULL;
