@@ -141,7 +141,8 @@ gimp_color_profile_combo_box_init (GimpColorProfileComboBox *combo_box)
   GtkCellRenderer *cell = gtk_cell_renderer_text_new ();
 
   g_object_set (cell,
-                "ellipsize", PANGO_ELLIPSIZE_END,
+                "width-chars", 42,
+                "ellipsize",   PANGO_ELLIPSIZE_END,
                 NULL);
 
 
@@ -517,7 +518,7 @@ gimp_color_profile_combo_box_set_active_file (GimpColorProfileComboBox *combo,
  *               This is a newly allocated string and should be released
  *               using g_free() when it is not any longer needed.
  *
- * Deprecated: use gimp_color_profile_combo_box_get_active_file() inatead.
+ * Deprecated: use gimp_color_profile_combo_box_get_active_file() instead.
  *
  * Since: 2.4
  **/
