@@ -638,12 +638,21 @@ gimp_color_profile_store_load_profile (GimpColorProfileStore *store,
 {
   GtkTreeIter  iter;
   gchar       *label = NULL;
-  gchar       *uri   = NULL;
+  gchar       *path  = NULL;
 
   if (gimp_scanner_parse_string (scanner, &label) &&
-      gimp_scanner_parse_string (scanner, &uri))
+      gimp_scanner_parse_string (scanner, &path))
     {
-      GFile *file = g_file_new_for_uri (uri);
+      GFile *file = NULL;
+
+      if (g_str_has_prefix (path, "file://"))
+        {
+          file = g_file_new_for_uri (path);
+        }
+      else
+        {
+          file = gimp_file_new_for_config_path (path, NULL);
+        }
 
       if (file)
         {
@@ -657,13 +666,13 @@ gimp_color_profile_store_load_profile (GimpColorProfileStore *store,
         }
 
       g_free (label);
-      g_free (uri);
+      g_free (path);
 
       return G_TOKEN_RIGHT_PAREN;
     }
 
   g_free (label);
-  g_free (uri);
+  g_free (path);
 
   return G_TOKEN_STRING;
 }
@@ -775,16 +784,16 @@ gimp_color_profile_store_save (GimpColorProfileStore  *store,
     {
       if (files[i] && labels[i])
         {
-          gchar *uri = g_file_get_uri (files[i]);
+          gchar *path = gimp_file_get_config_path (files[i], NULL);
 
-          if (uri)
+          if (path)
             {
               gimp_config_writer_open (writer, "color-profile");
               gimp_config_writer_string (writer, labels[i]);
-              gimp_config_writer_string (writer, uri);
+              gimp_config_writer_string (writer, path);
               gimp_config_writer_close (writer);
 
-              g_free (uri);
+              g_free (path);
             }
         }
 
