@@ -54,12 +54,21 @@ enum
 };
 
 
+typedef struct _GimpLCH  GimpLCH;
+
+struct _GimpLCH
+{
+  gdouble l, c, h, a;
+};
+
+
 typedef struct _GimpColorScalePrivate GimpColorScalePrivate;
 
 struct _GimpColorScalePrivate
 {
   GimpColorConfig          *config;
   GimpColorTransform       *transform;
+  guchar                    oog_color[3];
 
   GimpColorSelectorChannel  channel;
   GimpRGB                   rgb;
@@ -79,42 +88,44 @@ struct _GimpColorScalePrivate
                                      GimpColorScalePrivate)
 
 
-static void     gimp_color_scale_dispose             (GObject        *object);
-static void     gimp_color_scale_finalize            (GObject        *object);
-static void     gimp_color_scale_get_property        (GObject        *object,
-                                                      guint           property_id,
-                                                      GValue         *value,
-                                                      GParamSpec     *pspec);
-static void     gimp_color_scale_set_property        (GObject        *object,
-                                                      guint           property_id,
-                                                      const GValue   *value,
-                                                      GParamSpec     *pspec);
+static void     gimp_color_scale_dispose             (GObject          *object);
+static void     gimp_color_scale_finalize            (GObject          *object);
+static void     gimp_color_scale_get_property        (GObject          *object,
+                                                      guint             property_id,
+                                                      GValue           *value,
+                                                      GParamSpec       *pspec);
+static void     gimp_color_scale_set_property        (GObject          *object,
+                                                      guint             property_id,
+                                                      const GValue     *value,
+                                                      GParamSpec       *pspec);
 
-static void     gimp_color_scale_size_allocate       (GtkWidget      *widget,
-                                                      GtkAllocation  *allocation);
-static void     gimp_color_scale_state_flags_changed (GtkWidget      *widget,
-                                                      GtkStateFlags   previous_state);
-static gboolean gimp_color_scale_button_press        (GtkWidget      *widget,
-                                                      GdkEventButton *event);
-static gboolean gimp_color_scale_button_release      (GtkWidget      *widget,
-                                                      GdkEventButton *event);
-static gboolean gimp_color_scale_scroll              (GtkWidget      *widget,
-                                                      GdkEventScroll *event);
-static gboolean gimp_color_scale_draw                (GtkWidget      *widget,
-                                                      cairo_t        *cr);
+static void     gimp_color_scale_size_allocate       (GtkWidget        *widget,
+                                                      GtkAllocation    *allocation);
+static void     gimp_color_scale_state_flags_changed (GtkWidget        *widget,
+                                                      GtkStateFlags     previous_state);
+static gboolean gimp_color_scale_scroll              (GtkWidget        *widget,
+                                                      GdkEventScroll   *event);
+static gboolean gimp_color_scale_draw                (GtkWidget        *widget,
+                                                      cairo_t          *cr);
 
-static void     gimp_color_scale_render              (GimpColorScale *scale);
-static void     gimp_color_scale_render_alpha        (GimpColorScale *scale);
-static void     gimp_color_scale_render_stipple      (GimpColorScale *scale);
+static void     gimp_color_scale_render              (GimpColorScale   *scale);
+static void     gimp_color_scale_render_alpha        (GimpColorScale   *scale);
+static void     gimp_color_scale_render_stipple      (GimpColorScale   *scale);
 
-static void     gimp_color_scale_create_transform    (GimpColorScale *scale);
-static void     gimp_color_scale_destroy_transform   (GimpColorScale *scale);
+static void     gimp_color_scale_create_transform    (GimpColorScale   *scale);
+static void     gimp_color_scale_destroy_transform   (GimpColorScale   *scale);
+static void     gimp_color_scale_notify_config       (GimpColorConfig  *config,
+                                                      const GParamSpec *pspec,
+                                                      GimpColorScale   *scale);
 
 
-G_DEFINE_TYPE (GimpColorScale, gimp_color_scale, GTK_TYPE_SCALE)
+G_DEFINE_TYPE (GimpColorScale, gimp_color_scale, GTK_TYPE_RANGE)
 
 #define parent_class gimp_color_scale_parent_class
 
+static const Babl *fish_rgb_to_lch = NULL;
+static const Babl *fish_lch_to_rgb = NULL;
+
 
 static void
 gimp_color_scale_class_init (GimpColorScaleClass *klass)
@@ -129,11 +140,11 @@ gimp_color_scale_class_init (GimpColorScaleClass *klass)
 
   widget_class->size_allocate        = gimp_color_scale_size_allocate;
   widget_class->state_flags_changed  = gimp_color_scale_state_flags_changed;
-  widget_class->button_press_event   = gimp_color_scale_button_press;
-  widget_class->button_release_event = gimp_color_scale_button_release;
   widget_class->scroll_event         = gimp_color_scale_scroll;
   widget_class->draw                 = gimp_color_scale_draw;
 
+  gtk_widget_class_set_css_name (widget_class, "GimpColorScale");
+
   /**
    * GimpColorScale:channel:
    *
@@ -149,6 +160,18 @@ gimp_color_scale_class_init (GimpColorScaleClass *klass)
                                                       G_PARAM_CONSTRUCT));
 
   g_type_class_add_private (object_class, sizeof (GimpColorScalePrivate));
+
+  /*  This is so ugly... we have to babl_init() here so the binary
+   *  generated by gtk-doc to scan libgimpwidgets' types won't crash.
+   *  I didn't find a way to inject this line of code into the
+   *  generated source.
+   */
+  babl_init ();
+
+  fish_rgb_to_lch = babl_fish (babl_format ("R'G'B'A double"),
+                               babl_format ("CIE LCH(ab) double"));
+  fish_lch_to_rgb = babl_fish (babl_format ("CIE LCH(ab) double"),
+                               babl_format ("R'G'B' double"));
 }
 
 static void
@@ -156,12 +179,13 @@ gimp_color_scale_init (GimpColorScale *scale)
 {
   GimpColorScalePrivate *priv  = GET_PRIVATE (scale);
   GtkRange              *range = GTK_RANGE (scale);
+  GtkCssProvider        *css;
+
+  gtk_widget_set_can_focus (GTK_WIDGET (scale), TRUE);
 
   gtk_range_set_slider_size_fixed (range, TRUE);
   gtk_range_set_flippable (GTK_RANGE (scale), TRUE);
 
-  gtk_scale_set_draw_value (GTK_SCALE (scale), FALSE);
-
   priv->channel      = GIMP_COLOR_SELECTOR_VALUE;
   priv->needs_render = TRUE;
 
@@ -174,6 +198,22 @@ gimp_color_scale_init (GimpColorScale *scale)
   gimp_widget_track_monitor (GTK_WIDGET (scale),
                              G_CALLBACK (gimp_color_scale_destroy_transform),
                              NULL);
+
+  css = gtk_css_provider_new ();
+  gtk_css_provider_load_from_data (css,
+                                   "GimpColorScale contents {"
+                                   "  min-width:  24px;"
+                                   "  min-height: 24px;"
+                                   "}\n"
+                                   "GimpColorScale slider {"
+                                   "  min-width:  14px;"
+                                   "  min-height: 14px;"
+                                   "}",
+                                   -1, NULL);
+  gtk_style_context_add_provider (gtk_widget_get_style_context (GTK_WIDGET (scale)),
+                                  GTK_STYLE_PROVIDER (css),
+                                  GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+  g_object_unref (css);
 }
 
 static void
@@ -249,11 +289,15 @@ gimp_color_scale_size_allocate (GtkWidget     *widget,
 {
   GimpColorScalePrivate *priv  = GET_PRIVATE (widget);
   GtkRange              *range = GTK_RANGE (widget);
+  GtkStyleContext       *style = gtk_widget_get_style_context (widget);
   GdkRectangle           range_rect;
   gint                   focus = 0;
   gint                   trough_border;
   gint                   scale_width;
   gint                   scale_height;
+  gint                   slider_start;
+  gint                   slider_end;
+  gint                   slider_size;
 
   gtk_widget_style_get (widget,
                         "trough-border", &trough_border,
@@ -270,14 +314,17 @@ gimp_color_scale_size_allocate (GtkWidget     *widget,
       focus += focus_padding;
     }
 
-  gtk_range_set_min_slider_size (range,
-                                 (MIN (allocation->width,
-                                       allocation->height) - 2 * focus) / 2);
+  gtk_range_set_min_slider_size (range, 14);
 
   if (GTK_WIDGET_CLASS (parent_class)->size_allocate)
     GTK_WIDGET_CLASS (parent_class)->size_allocate (widget, allocation);
 
   gtk_range_get_range_rect (range, &range_rect);
+  gtk_range_get_slider_range (range, &slider_start, &slider_end);
+  slider_size = slider_end - slider_start;
+
+  g_printerr ("slider_size = %d   min = %d\n",
+              slider_size, gtk_range_get_min_slider_size (range));
 
   scale_width  = range_rect.width  - 2 * (focus + trough_border);
   scale_height = range_rect.height - 2 * (focus + trough_border);
@@ -285,13 +332,13 @@ gimp_color_scale_size_allocate (GtkWidget     *widget,
   switch (gtk_orientable_get_orientation (GTK_ORIENTABLE (range)))
     {
     case GTK_ORIENTATION_HORIZONTAL:
-      scale_width  -= gtk_range_get_min_slider_size (range) - 1;
+      scale_width  -= slider_size / 2;
       scale_height -= 2;
       break;
 
     case GTK_ORIENTATION_VERTICAL:
       scale_width  -= 2;
-      scale_height -= gtk_range_get_min_slider_size (range) - 1;
+      scale_height -= slider_size / 2;
       break;
     }
 
@@ -324,52 +371,6 @@ gimp_color_scale_state_flags_changed (GtkWidget     *widget,
                                                           previous_state);
 }
 
-static gboolean
-gimp_color_scale_button_press (GtkWidget      *widget,
-                               GdkEventButton *event)
-{
-  if (event->button == 1)
-    {
-      GdkEventButton *my_event;
-      gboolean        retval;
-
-      my_event = (GdkEventButton *) gdk_event_copy ((GdkEvent *) event);
-      my_event->button = 2;
-
-      retval = GTK_WIDGET_CLASS (parent_class)->button_press_event (widget,
-                                                                    my_event);
-
-      gdk_event_free ((GdkEvent *) my_event);
-
-      return retval;
-    }
-
-  return GTK_WIDGET_CLASS (parent_class)->button_press_event (widget, event);
-}
-
-static gboolean
-gimp_color_scale_button_release (GtkWidget      *widget,
-                                 GdkEventButton *event)
-{
-  if (event->button == 1)
-    {
-      GdkEventButton *my_event;
-      gboolean        retval;
-
-      my_event = (GdkEventButton *) gdk_event_copy ((GdkEvent *) event);
-      my_event->button = 2;
-
-      retval = GTK_WIDGET_CLASS (parent_class)->button_release_event (widget,
-                                                                      my_event);
-
-      gdk_event_free ((GdkEvent *) my_event);
-
-      return retval;
-    }
-
-  return GTK_WIDGET_CLASS (parent_class)->button_release_event (widget, event);
-}
-
 static gboolean
 gimp_color_scale_scroll (GtkWidget      *widget,
                          GdkEventScroll *event)
@@ -421,6 +422,7 @@ gimp_color_scale_draw (GtkWidget *widget,
   gint                   focus = 0;
   gint                   trough_border;
   gint                   slider_start;
+  gint                   slider_end;
   gint                   slider_size;
   gint                   x, y;
   gint                   w, h;
@@ -448,14 +450,15 @@ gimp_color_scale_draw (GtkWidget *widget,
     }
 
   gtk_range_get_range_rect (range, &range_rect);
-  gtk_range_get_slider_range (range, &slider_start, NULL);
+  gtk_range_get_slider_range (range, &slider_start, &slider_end);
+  slider_size = slider_end - slider_start;
 
   x = range_rect.x + focus;
   y = range_rect.y + focus;
   w = range_rect.width  - 2 * focus;
   h = range_rect.height - 2 * focus;
 
-  slider_size = gtk_range_get_min_slider_size (range) / 2;
+  slider_size /= 2;
 
   if (priv->needs_render)
     {
@@ -515,14 +518,14 @@ gimp_color_scale_draw (GtkWidget *widget,
     {
     case GTK_ORIENTATION_HORIZONTAL:
       cairo_set_source_surface (cr, buffer,
-                                x + trough_border + slider_size,
+                                x + trough_border + slider_size / 2 + 1,
                                 y + trough_border + 1);
       break;
 
     case GTK_ORIENTATION_VERTICAL:
       cairo_set_source_surface (cr, buffer,
                                 x + trough_border + 1,
-                                y + trough_border + slider_size);
+                                y + trough_border + slider_size / 2 + 1);
       break;
     }
 
@@ -717,7 +720,7 @@ gimp_color_scale_set_color_config (GimpColorScale  *scale,
       if (priv->config)
         {
           g_signal_handlers_disconnect_by_func (priv->config,
-                                                gimp_color_scale_destroy_transform,
+                                                gimp_color_scale_notify_config,
                                                 scale);
           g_object_unref (priv->config);
 
@@ -730,9 +733,11 @@ gimp_color_scale_set_color_config (GimpColorScale  *scale,
         {
           g_object_ref (priv->config);
 
-          g_signal_connect_swapped (priv->config, "notify",
-                                    G_CALLBACK (gimp_color_scale_destroy_transform),
-                                    scale);
+          g_signal_connect (priv->config, "notify",
+                            G_CALLBACK (gimp_color_scale_notify_config),
+                            scale);
+
+          gimp_color_scale_notify_config (priv->config, NULL, scale);
         }
     }
 }
@@ -768,9 +773,12 @@ gimp_color_scale_render (GimpColorScale *scale)
   GtkRange              *range = GTK_RANGE (scale);
   GimpRGB                rgb;
   GimpHSV                hsv;
+  GimpLCH                lch;
+  gint                   multiplier = 1;
   guint                  x, y;
   gdouble               *channel_value = NULL; /* shut up compiler */
-  gboolean               to_rgb        = FALSE;
+  gboolean               from_hsv      = FALSE;
+  gboolean               from_lch      = FALSE;
   gboolean               invert;
   guchar                *buf;
   guchar                *d;
@@ -786,16 +794,22 @@ gimp_color_scale_render (GimpColorScale *scale)
 
   rgb = priv->rgb;
   hsv = priv->hsv;
+  babl_process (fish_rgb_to_lch, &rgb, &lch, 1);
 
   switch (priv->channel)
     {
     case GIMP_COLOR_SELECTOR_HUE:        channel_value = &hsv.h; break;
     case GIMP_COLOR_SELECTOR_SATURATION: channel_value = &hsv.s; break;
     case GIMP_COLOR_SELECTOR_VALUE:      channel_value = &hsv.v; break;
+
     case GIMP_COLOR_SELECTOR_RED:        channel_value = &rgb.r; break;
     case GIMP_COLOR_SELECTOR_GREEN:      channel_value = &rgb.g; break;
     case GIMP_COLOR_SELECTOR_BLUE:       channel_value = &rgb.b; break;
     case GIMP_COLOR_SELECTOR_ALPHA:      channel_value = &rgb.a; break;
+
+    case GIMP_COLOR_SELECTOR_LCH_LIGHTNESS: channel_value = &lch.l; break;
+    case GIMP_COLOR_SELECTOR_LCH_CHROMA:    channel_value = &lch.c; break;
+    case GIMP_COLOR_SELECTOR_LCH_HUE:       channel_value = &lch.h; break;
     }
 
   switch (priv->channel)
@@ -803,7 +817,20 @@ gimp_color_scale_render (GimpColorScale *scale)
     case GIMP_COLOR_SELECTOR_HUE:
     case GIMP_COLOR_SELECTOR_SATURATION:
     case GIMP_COLOR_SELECTOR_VALUE:
-      to_rgb = TRUE;
+      from_hsv = TRUE;
+      break;
+
+    case GIMP_COLOR_SELECTOR_LCH_LIGHTNESS:
+      multiplier = 100;
+      from_lch = TRUE;
+      break;
+    case GIMP_COLOR_SELECTOR_LCH_CHROMA:
+      multiplier = 100;
+      from_lch = TRUE;
+      break;
+    case GIMP_COLOR_SELECTOR_LCH_HUE:
+      multiplier = 360;
+      from_lch = TRUE;
       break;
 
     default:
@@ -817,18 +844,31 @@ gimp_color_scale_render (GimpColorScale *scale)
     case GTK_ORIENTATION_HORIZONTAL:
       for (x = 0, d = buf; x < priv->width; x++, d += 4)
         {
-          gdouble value = (gdouble) x / (gdouble) (priv->width - 1);
+          gdouble value = (gdouble) x * multiplier / (gdouble) (priv->width - 1);
           guchar  r, g, b;
 
           if (invert)
-            value = 1.0 - value;
+            value = multiplier - value;
 
           *channel_value = value;
 
-          if (to_rgb)
+          if (from_hsv)
             gimp_hsv_to_rgb (&hsv, &rgb);
+          else if (from_lch)
+            babl_process (fish_lch_to_rgb, &lch, &rgb, 1);
 
-          gimp_rgb_get_uchar (&rgb, &r, &g, &b);
+          if (rgb.r < 0.0 || rgb.r > 1.0 ||
+              rgb.g < 0.0 || rgb.g > 1.0 ||
+              rgb.b < 0.0 || rgb.b > 1.0)
+            {
+              r = priv->oog_color[0];
+              g = priv->oog_color[1];
+              b = priv->oog_color[2];
+            }
+          else
+            {
+              gimp_rgb_get_uchar (&rgb, &r, &g, &b);
+            }
 
           GIMP_CAIRO_RGB24_SET_PIXEL (d, r, g, b);
         }
@@ -844,18 +884,31 @@ gimp_color_scale_render (GimpColorScale *scale)
     case GTK_ORIENTATION_VERTICAL:
       for (y = 0; y < priv->height; y++)
         {
-          gdouble value = (gdouble) y / (gdouble) (priv->height - 1);
+          gdouble value = (gdouble) y * multiplier / (gdouble) (priv->height - 1);
           guchar  r, g, b;
 
           if (invert)
-            value = 1.0 - value;
+            value = multiplier - value;
 
           *channel_value = value;
 
-          if (to_rgb)
+          if (from_hsv)
             gimp_hsv_to_rgb (&hsv, &rgb);
+          else if (from_lch)
+            babl_process (fish_lch_to_rgb, &lch, &rgb, 1);
 
-          gimp_rgb_get_uchar (&rgb, &r, &g, &b);
+          if (rgb.r < 0.0 || rgb.r > 1.0 ||
+              rgb.g < 0.0 || rgb.g > 1.0 ||
+              rgb.b < 0.0 || rgb.b > 1.0)
+            {
+              r = priv->oog_color[0];
+              g = priv->oog_color[1];
+              b = priv->oog_color[2];
+            }
+          else
+            {
+              gimp_rgb_get_uchar (&rgb, &r, &g, &b);
+            }
 
           for (x = 0, d = buf; x < priv->width; x++, d += 4)
             {
@@ -1071,3 +1124,19 @@ gimp_color_scale_destroy_transform (GimpColorScale *scale)
 
   gtk_widget_queue_draw (GTK_WIDGET (scale));
 }
+
+static void
+gimp_color_scale_notify_config (GimpColorConfig  *config,
+                                const GParamSpec *pspec,
+                                GimpColorScale   *scale)
+{
+  GimpColorScalePrivate *priv = GET_PRIVATE (scale);
+
+  gimp_color_scale_destroy_transform (scale);
+
+  gimp_rgb_get_uchar (&config->out_of_gamut_color,
+                      priv->oog_color,
+                      priv->oog_color + 1,
+                      priv->oog_color + 2);
+  priv->needs_render = TRUE;
+}
