@@ -176,7 +176,7 @@ gimp_color_selection_class_init (GimpColorSelectionClass *klass)
 static void
 gimp_color_selection_init (GimpColorSelection *selection)
 {
-  GimpColorSelectionPrivate *private = GET_PRIVATE (selection);
+  GimpColorSelectionPrivate *priv = GET_PRIVATE (selection);
   GtkWidget                 *main_hbox;
   GtkWidget                 *hbox;
   GtkWidget                 *vbox;
@@ -187,25 +187,25 @@ gimp_color_selection_init (GimpColorSelection *selection)
   GtkSizeGroup              *new_group;
   GtkSizeGroup              *old_group;
 
-  private->show_alpha = TRUE;
+  priv->show_alpha = TRUE;
 
   gtk_orientable_set_orientation (GTK_ORIENTABLE (selection),
                                   GTK_ORIENTATION_VERTICAL);
 
-  gimp_rgba_set (&private->rgb, 0.0, 0.0, 0.0, 1.0);
-  gimp_rgb_to_hsv (&private->rgb, &private->hsv);
+  gimp_rgba_set (&priv->rgb, 0.0, 0.0, 0.0, 1.0);
+  gimp_rgb_to_hsv (&priv->rgb, &priv->hsv);
 
-  private->channel = GIMP_COLOR_SELECTOR_HUE;
+  priv->channel = GIMP_COLOR_SELECTOR_HUE;
 
   main_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
   gtk_box_pack_start (GTK_BOX (selection), main_hbox, TRUE, TRUE, 0);
   gtk_widget_show (main_hbox);
 
   /*  The left vbox with the notebook  */
-  private->left_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
-  gtk_box_pack_start (GTK_BOX (main_hbox), private->left_vbox,
+  priv->left_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
+  gtk_box_pack_start (GTK_BOX (main_hbox), priv->left_vbox,
                       TRUE, TRUE, 0);
-  gtk_widget_show (private->left_vbox);
+  gtk_widget_show (priv->left_vbox);
 
   if (_gimp_ensure_modules_func)
     {
@@ -213,31 +213,31 @@ gimp_color_selection_init (GimpColorSelection *selection)
       _gimp_ensure_modules_func ();
     }
 
-  private->notebook = gimp_color_selector_new (GIMP_TYPE_COLOR_NOTEBOOK,
-                                                 &private->rgb,
-                                                 &private->hsv,
-                                                 private->channel);
+  priv->notebook = gimp_color_selector_new (GIMP_TYPE_COLOR_NOTEBOOK,
+                                            &priv->rgb,
+                                            &priv->hsv,
+                                            priv->channel);
 
   if (_gimp_ensure_modules_func)
     g_type_class_unref (g_type_class_peek (GIMP_TYPE_COLOR_SELECT));
 
   gimp_color_selector_set_toggles_visible
-    (GIMP_COLOR_SELECTOR (private->notebook), FALSE);
-  gtk_box_pack_start (GTK_BOX (private->left_vbox), private->notebook,
+    (GIMP_COLOR_SELECTOR (priv->notebook), FALSE);
+  gtk_box_pack_start (GTK_BOX (priv->left_vbox), priv->notebook,
                       TRUE, TRUE, 0);
-  gtk_widget_show (private->notebook);
+  gtk_widget_show (priv->notebook);
 
-  g_signal_connect (private->notebook, "color-changed",
+  g_signal_connect (priv->notebook, "color-changed",
                     G_CALLBACK (gimp_color_selection_notebook_changed),
                     selection);
-  g_signal_connect (gimp_color_notebook_get_notebook (GIMP_COLOR_NOTEBOOK (private->notebook)),
+  g_signal_connect (gimp_color_notebook_get_notebook (GIMP_COLOR_NOTEBOOK (priv->notebook)),
                     "switch-page",
                     G_CALLBACK (gimp_color_selection_switch_page),
                     selection);
 
   /*  The hbox for the color_areas  */
   hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
-  gtk_box_pack_end (GTK_BOX (private->left_vbox), hbox, FALSE, FALSE, 0);
+  gtk_box_pack_end (GTK_BOX (priv->left_vbox), hbox, FALSE, FALSE, 0);
   gtk_widget_show (hbox);
 
   /*  The labels  */
@@ -246,7 +246,7 @@ gimp_color_selection_init (GimpColorSelection *selection)
   gtk_widget_show (vbox);
 
   label = gtk_label_new (_("Current:"));
-  gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
+  gtk_label_set_xalign (GTK_LABEL (label), 1.0);
   gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
   gtk_widget_show (label);
 
@@ -255,7 +255,7 @@ gimp_color_selection_init (GimpColorSelection *selection)
   g_object_unref (new_group);
 
   label = gtk_label_new (_("Old:"));
-  gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
+  gtk_label_set_xalign (GTK_LABEL (label), 1.0);
   gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
   gtk_widget_show (label);
 
@@ -273,58 +273,58 @@ gimp_color_selection_init (GimpColorSelection *selection)
   gtk_container_add (GTK_CONTAINER (frame), vbox);
   gtk_widget_show (vbox);
 
-  private->new_color = gimp_color_area_new (&private->rgb,
-                                              private->show_alpha ?
-                                              GIMP_COLOR_AREA_SMALL_CHECKS :
-                                              GIMP_COLOR_AREA_FLAT,
-                                              GDK_BUTTON1_MASK |
-                                              GDK_BUTTON2_MASK);
-  gtk_size_group_add_widget (new_group, private->new_color);
-  gtk_box_pack_start (GTK_BOX (vbox), private->new_color, FALSE, FALSE, 0);
-  gtk_widget_show (private->new_color);
+  priv->new_color = gimp_color_area_new (&priv->rgb,
+                                         priv->show_alpha ?
+                                         GIMP_COLOR_AREA_SMALL_CHECKS :
+                                         GIMP_COLOR_AREA_FLAT,
+                                         GDK_BUTTON1_MASK |
+                                         GDK_BUTTON2_MASK);
+  gtk_size_group_add_widget (new_group, priv->new_color);
+  gtk_box_pack_start (GTK_BOX (vbox), priv->new_color, FALSE, FALSE, 0);
+  gtk_widget_show (priv->new_color);
 
-  g_signal_connect (private->new_color, "color-changed",
+  g_signal_connect (priv->new_color, "color-changed",
                     G_CALLBACK (gimp_color_selection_new_color_changed),
                     selection);
 
-  private->old_color = gimp_color_area_new (&private->rgb,
-                                              private->show_alpha ?
-                                              GIMP_COLOR_AREA_SMALL_CHECKS :
-                                              GIMP_COLOR_AREA_FLAT,
-                                              GDK_BUTTON1_MASK |
-                                              GDK_BUTTON2_MASK);
-  gtk_drag_dest_unset (private->old_color);
-  gtk_size_group_add_widget (old_group, private->old_color);
-  gtk_box_pack_start (GTK_BOX (vbox), private->old_color, FALSE, FALSE, 0);
-  gtk_widget_show (private->old_color);
+  priv->old_color = gimp_color_area_new (&priv->rgb,
+                                         priv->show_alpha ?
+                                         GIMP_COLOR_AREA_SMALL_CHECKS :
+                                         GIMP_COLOR_AREA_FLAT,
+                                         GDK_BUTTON1_MASK |
+                                         GDK_BUTTON2_MASK);
+  gtk_drag_dest_unset (priv->old_color);
+  gtk_size_group_add_widget (old_group, priv->old_color);
+  gtk_box_pack_start (GTK_BOX (vbox), priv->old_color, FALSE, FALSE, 0);
+  gtk_widget_show (priv->old_color);
 
   /*  The right vbox with color scales  */
-  private->right_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
-  gtk_box_pack_start (GTK_BOX (main_hbox), private->right_vbox,
+  priv->right_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
+  gtk_box_pack_start (GTK_BOX (main_hbox), priv->right_vbox,
                       TRUE, TRUE, 0);
-  gtk_widget_show (private->right_vbox);
+  gtk_widget_show (priv->right_vbox);
 
-  private->scales = gimp_color_selector_new (GIMP_TYPE_COLOR_SCALES,
-                                               &private->rgb,
-                                               &private->hsv,
-                                               private->channel);
+  priv->scales = gimp_color_selector_new (GIMP_TYPE_COLOR_SCALES,
+                                          &priv->rgb,
+                                          &priv->hsv,
+                                          priv->channel);
   gimp_color_selector_set_toggles_visible
-    (GIMP_COLOR_SELECTOR (private->scales), TRUE);
-  gimp_color_selector_set_show_alpha (GIMP_COLOR_SELECTOR (private->scales),
-                                      private->show_alpha);
-  gtk_box_pack_start (GTK_BOX (private->right_vbox), private->scales,
+    (GIMP_COLOR_SELECTOR (priv->scales), TRUE);
+  gimp_color_selector_set_show_alpha (GIMP_COLOR_SELECTOR (priv->scales),
+                                      priv->show_alpha);
+  gtk_box_pack_start (GTK_BOX (priv->right_vbox), priv->scales,
                       TRUE, TRUE, 0);
-  gtk_widget_show (private->scales);
+  gtk_widget_show (priv->scales);
 
-  g_signal_connect (private->scales, "channel-changed",
+  g_signal_connect (priv->scales, "channel-changed",
                     G_CALLBACK (gimp_color_selection_channel_changed),
                     selection);
-  g_signal_connect (private->scales, "color-changed",
+  g_signal_connect (priv->scales, "color-changed",
                     G_CALLBACK (gimp_color_selection_scales_changed),
                     selection);
 
   hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
-  gtk_box_pack_start (GTK_BOX (private->right_vbox), hbox, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (priv->right_vbox), hbox, FALSE, FALSE, 0);
   gtk_widget_show (hbox);
 
   /*  The color picker  */
@@ -402,27 +402,27 @@ void
 gimp_color_selection_set_show_alpha (GimpColorSelection *selection,
                                      gboolean            show_alpha)
 {
-  GimpColorSelectionPrivate *private;
+  GimpColorSelectionPrivate *priv;
 
   g_return_if_fail (GIMP_IS_COLOR_SELECTION (selection));
 
-  private = GET_PRIVATE (selection);
+  priv = GET_PRIVATE (selection);
 
-  if (show_alpha != private->show_alpha)
+  if (show_alpha != priv->show_alpha)
     {
-      private->show_alpha = show_alpha ? TRUE : FALSE;
+      priv->show_alpha = show_alpha ? TRUE : FALSE;
 
       gimp_color_selector_set_show_alpha
-        (GIMP_COLOR_SELECTOR (private->notebook), private->show_alpha);
+        (GIMP_COLOR_SELECTOR (priv->notebook), priv->show_alpha);
       gimp_color_selector_set_show_alpha
-        (GIMP_COLOR_SELECTOR (private->scales), private->show_alpha);
+        (GIMP_COLOR_SELECTOR (priv->scales), priv->show_alpha);
 
-      gimp_color_area_set_type (GIMP_COLOR_AREA (private->new_color),
-                                private->show_alpha ?
+      gimp_color_area_set_type (GIMP_COLOR_AREA (priv->new_color),
+                                priv->show_alpha ?
                                 GIMP_COLOR_AREA_SMALL_CHECKS :
                                 GIMP_COLOR_AREA_FLAT);
-      gimp_color_area_set_type (GIMP_COLOR_AREA (private->old_color),
-                                private->show_alpha ?
+      gimp_color_area_set_type (GIMP_COLOR_AREA (priv->old_color),
+                                priv->show_alpha ?
                                 GIMP_COLOR_AREA_SMALL_CHECKS :
                                 GIMP_COLOR_AREA_FLAT);
     }
@@ -455,15 +455,15 @@ void
 gimp_color_selection_set_color (GimpColorSelection *selection,
                                 const GimpRGB      *color)
 {
-  GimpColorSelectionPrivate *private;
+  GimpColorSelectionPrivate *priv;
 
   g_return_if_fail (GIMP_IS_COLOR_SELECTION (selection));
   g_return_if_fail (color != NULL);
 
-  private = GET_PRIVATE (selection);
+  priv = GET_PRIVATE (selection);
 
-  private->rgb = *color;
-  gimp_rgb_to_hsv (&private->rgb, &private->hsv);
+  priv->rgb = *color;
+  gimp_rgb_to_hsv (&priv->rgb, &priv->hsv);
 
   gimp_color_selection_update (selection, UPDATE_ALL);
 
@@ -498,14 +498,14 @@ void
 gimp_color_selection_set_old_color (GimpColorSelection *selection,
                                     const GimpRGB      *color)
 {
-  GimpColorSelectionPrivate *private;
+  GimpColorSelectionPrivate *priv;
 
   g_return_if_fail (GIMP_IS_COLOR_SELECTION (selection));
   g_return_if_fail (color != NULL);
 
-  private = GET_PRIVATE (selection);
+  priv = GET_PRIVATE (selection);
 
-  gimp_color_area_set_color (GIMP_COLOR_AREA (private->old_color), color);
+  gimp_color_area_set_color (GIMP_COLOR_AREA (priv->old_color), color);
 }
 
 /**
@@ -519,14 +519,14 @@ void
 gimp_color_selection_get_old_color (GimpColorSelection *selection,
                                     GimpRGB            *color)
 {
-  GimpColorSelectionPrivate *private;
+  GimpColorSelectionPrivate *priv;
 
   g_return_if_fail (GIMP_IS_COLOR_SELECTION (selection));
   g_return_if_fail (color != NULL);
 
-  private = GET_PRIVATE (selection);
+  priv = GET_PRIVATE (selection);
 
-  gimp_color_area_get_color (GIMP_COLOR_AREA (private->old_color), color);
+  gimp_color_area_get_color (GIMP_COLOR_AREA (priv->old_color), color);
 }
 
 /**
@@ -538,14 +538,14 @@ gimp_color_selection_get_old_color (GimpColorSelection *selection,
 void
 gimp_color_selection_reset (GimpColorSelection *selection)
 {
-  GimpColorSelectionPrivate *private;
+  GimpColorSelectionPrivate *priv;
   GimpRGB                    color;
 
   g_return_if_fail (GIMP_IS_COLOR_SELECTION (selection));
 
-  private = GET_PRIVATE (selection);
+  priv = GET_PRIVATE (selection);
 
-  gimp_color_area_get_color (GIMP_COLOR_AREA (private->old_color), &color);
+  gimp_color_area_get_color (GIMP_COLOR_AREA (priv->old_color), &color);
   gimp_color_selection_set_color (selection, &color);
 }
 
@@ -576,17 +576,21 @@ void
 gimp_color_selection_set_config (GimpColorSelection *selection,
                                  GimpColorConfig    *config)
 {
-  GimpColorSelectionPrivate *private;
+  GimpColorSelectionPrivate *priv;
 
   g_return_if_fail (GIMP_IS_COLOR_SELECTION (selection));
   g_return_if_fail (config == NULL || GIMP_IS_COLOR_CONFIG (config));
 
-  private = GET_PRIVATE (selection);
+  priv = GET_PRIVATE (selection);
 
-  gimp_color_selector_set_config (GIMP_COLOR_SELECTOR (private->notebook),
+  gimp_color_selector_set_config (GIMP_COLOR_SELECTOR (priv->notebook),
                                   config);
-  gimp_color_selector_set_config (GIMP_COLOR_SELECTOR (private->scales),
+  gimp_color_selector_set_config (GIMP_COLOR_SELECTOR (priv->scales),
                                   config);
+  gimp_color_area_set_color_config (GIMP_COLOR_AREA (priv->old_color),
+                                    config);
+  gimp_color_area_set_color_config (GIMP_COLOR_AREA (priv->new_color),
+                                    config);
 }
 
 /**
@@ -630,8 +634,8 @@ gimp_color_selection_switch_page (GtkWidget          *widget,
                                   guint               page_num,
                                   GimpColorSelection *selection)
 {
-  GimpColorSelectionPrivate *private  = GET_PRIVATE (selection);
-  GimpColorNotebook         *notebook = GIMP_COLOR_NOTEBOOK (private->notebook);
+  GimpColorSelectionPrivate *priv     = GET_PRIVATE (selection);
+  GimpColorNotebook         *notebook = GIMP_COLOR_NOTEBOOK (priv->notebook);
   GimpColorSelector         *current;
   gboolean                   sensitive;
 
@@ -640,7 +644,7 @@ gimp_color_selection_switch_page (GtkWidget          *widget,
   sensitive = (GIMP_COLOR_SELECTOR_GET_CLASS (current)->set_channel != NULL);
 
   gimp_color_selector_set_toggles_sensitive
-    (GIMP_COLOR_SELECTOR (private->scales), sensitive);
+    (GIMP_COLOR_SELECTOR (priv->scales), sensitive);
 }
 
 static void
@@ -649,10 +653,10 @@ gimp_color_selection_notebook_changed (GimpColorSelector  *selector,
                                        const GimpHSV      *hsv,
                                        GimpColorSelection *selection)
 {
-  GimpColorSelectionPrivate *private = GET_PRIVATE (selection);
+  GimpColorSelectionPrivate *priv = GET_PRIVATE (selection);
 
-  private->hsv = *hsv;
-  private->rgb = *rgb;
+  priv->hsv = *hsv;
+  priv->rgb = *rgb;
 
   gimp_color_selection_update (selection,
                                UPDATE_SCALES | UPDATE_ENTRY | UPDATE_COLOR);
@@ -665,10 +669,10 @@ gimp_color_selection_scales_changed (GimpColorSelector  *selector,
                                      const GimpHSV      *hsv,
                                      GimpColorSelection *selection)
 {
-  GimpColorSelectionPrivate *private = GET_PRIVATE (selection);
+  GimpColorSelectionPrivate *priv = GET_PRIVATE (selection);
 
-  private->rgb = *rgb;
-  private->hsv = *hsv;
+  priv->rgb = *rgb;
+  priv->hsv = *hsv;
 
   gimp_color_selection_update (selection,
                                UPDATE_ENTRY | UPDATE_NOTEBOOK | UPDATE_COLOR);
@@ -687,11 +691,11 @@ static void
 gimp_color_selection_entry_changed (GimpColorHexEntry  *entry,
                                     GimpColorSelection *selection)
 {
-  GimpColorSelectionPrivate *private = GET_PRIVATE (selection);
+  GimpColorSelectionPrivate *priv = GET_PRIVATE (selection);
 
-  gimp_color_hex_entry_get_color (entry, &private->rgb);
+  gimp_color_hex_entry_get_color (entry, &priv->rgb);
 
-  gimp_rgb_to_hsv (&private->rgb, &private->hsv);
+  gimp_rgb_to_hsv (&priv->rgb, &priv->hsv);
 
   gimp_color_selection_update (selection,
                                UPDATE_NOTEBOOK | UPDATE_SCALES | UPDATE_COLOR);
@@ -703,22 +707,22 @@ gimp_color_selection_channel_changed (GimpColorSelector        *selector,
                                       GimpColorSelectorChannel  channel,
                                       GimpColorSelection       *selection)
 {
-  GimpColorSelectionPrivate *private = GET_PRIVATE (selection);
+  GimpColorSelectionPrivate *priv = GET_PRIVATE (selection);
 
-  private->channel = channel;
+  priv->channel = channel;
 
-  gimp_color_selector_set_channel (GIMP_COLOR_SELECTOR (private->notebook),
-                                   private->channel);
+  gimp_color_selector_set_channel (GIMP_COLOR_SELECTOR (priv->notebook),
+                                   priv->channel);
 }
 
 static void
 gimp_color_selection_new_color_changed (GtkWidget          *widget,
                                         GimpColorSelection *selection)
 {
-  GimpColorSelectionPrivate *private = GET_PRIVATE (selection);
+  GimpColorSelectionPrivate *priv = GET_PRIVATE (selection);
 
-  gimp_color_area_get_color (GIMP_COLOR_AREA (widget), &private->rgb);
-  gimp_rgb_to_hsv (&private->rgb, &private->hsv);
+  gimp_color_area_get_color (GIMP_COLOR_AREA (widget), &priv->rgb);
+  gimp_rgb_to_hsv (&priv->rgb, &priv->hsv);
 
   gimp_color_selection_update (selection,
                                UPDATE_NOTEBOOK | UPDATE_SCALES | UPDATE_ENTRY);
@@ -729,34 +733,34 @@ static void
 gimp_color_selection_update (GimpColorSelection *selection,
                              UpdateType          update)
 {
-  GimpColorSelectionPrivate *private = GET_PRIVATE (selection);
+  GimpColorSelectionPrivate *priv = GET_PRIVATE (selection);
 
   if (update & UPDATE_NOTEBOOK)
     {
-      g_signal_handlers_block_by_func (private->notebook,
+      g_signal_handlers_block_by_func (priv->notebook,
                                        gimp_color_selection_notebook_changed,
                                        selection);
 
-      gimp_color_selector_set_color (GIMP_COLOR_SELECTOR (private->notebook),
-                                     &private->rgb,
-                                     &private->hsv);
+      gimp_color_selector_set_color (GIMP_COLOR_SELECTOR (priv->notebook),
+                                     &priv->rgb,
+                                     &priv->hsv);
 
-      g_signal_handlers_unblock_by_func (private->notebook,
+      g_signal_handlers_unblock_by_func (priv->notebook,
                                          gimp_color_selection_notebook_changed,
                                          selection);
     }
 
   if (update & UPDATE_SCALES)
     {
-      g_signal_handlers_block_by_func (private->scales,
+      g_signal_handlers_block_by_func (priv->scales,
                                        gimp_color_selection_scales_changed,
                                        selection);
 
-      gimp_color_selector_set_color (GIMP_COLOR_SELECTOR (private->scales),
-                                     &private->rgb,
-                                     &private->hsv);
+      gimp_color_selector_set_color (GIMP_COLOR_SELECTOR (priv->scales),
+                                     &priv->rgb,
+                                     &priv->hsv);
 
-      g_signal_handlers_unblock_by_func (private->scales,
+      g_signal_handlers_unblock_by_func (priv->scales,
                                          gimp_color_selection_scales_changed,
                                          selection);
     }
@@ -771,7 +775,7 @@ gimp_color_selection_update (GimpColorSelection *selection,
                                        gimp_color_selection_entry_changed,
                                        selection);
 
-      gimp_color_hex_entry_set_color (entry, &private->rgb);
+      gimp_color_hex_entry_set_color (entry, &priv->rgb);
 
       g_signal_handlers_unblock_by_func (entry,
                                          gimp_color_selection_entry_changed,
@@ -780,14 +784,14 @@ gimp_color_selection_update (GimpColorSelection *selection,
 
   if (update & UPDATE_COLOR)
     {
-      g_signal_handlers_block_by_func (private->new_color,
+      g_signal_handlers_block_by_func (priv->new_color,
                                        gimp_color_selection_new_color_changed,
                                        selection);
 
-      gimp_color_area_set_color (GIMP_COLOR_AREA (private->new_color),
-                                 &private->rgb);
+      gimp_color_area_set_color (GIMP_COLOR_AREA (priv->new_color),
+                                 &priv->rgb);
 
-      g_signal_handlers_unblock_by_func (private->new_color,
+      g_signal_handlers_unblock_by_func (priv->new_color,
                                          gimp_color_selection_new_color_changed,
                                          selection);
     }
