@@ -28,6 +28,8 @@
 #include "gimpdialog.h"
 #include "gimphelpui.h"
 
+#include "libgimp/libgimp-intl.h"
+
 
 /**
  * SECTION: gimpdialog
@@ -129,7 +131,8 @@ gimp_dialog_class_init (GimpDialogClass *klass)
   g_object_class_install_property (object_class, PROP_HELP_ID,
                                    g_param_spec_string ("help-id", NULL, NULL,
                                                         NULL,
-                                                        GIMP_PARAM_READWRITE));
+                                                        GIMP_PARAM_READWRITE |
+                                                        G_PARAM_CONSTRUCT));
 
   /**
    * GimpDialog:parent:
@@ -170,7 +173,7 @@ gimp_dialog_constructed (GObject *object)
       GtkDialog *dialog      = GTK_DIALOG (object);
       GtkWidget *action_area = gtk_dialog_get_action_area (dialog);
 
-      private->help_button = gtk_button_new_from_stock (GTK_STOCK_HELP);
+      private->help_button = gtk_button_new_with_mnemonic (_("_Help"));
 
       gtk_box_pack_end (GTK_BOX (action_area), private->help_button,
                         FALSE, TRUE, 0);
