@@ -560,7 +560,7 @@ gimp_size_entry_attach_label (GimpSizeEntry *gse,
       g_list_free (children);
     }
 
-  gtk_misc_set_alignment (GTK_MISC (label), alignment, 0.5);
+  gtk_label_set_xalign (GTK_LABEL (label), alignment);
 
   gtk_table_attach (GTK_TABLE (gse), label, column, column+1, row, row+1,
                     GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
@@ -1367,7 +1367,7 @@ gimp_size_entry_eevl_unit_resolver (const gchar      *identifier,
   GimpSizeEntryField *gsef                 = (GimpSizeEntryField *) data;
   gboolean            resolve_default_unit = (identifier == NULL);
   GimpUnit            unit;
-  
+
   g_return_val_if_fail (gsef, FALSE);
   g_return_val_if_fail (result != NULL, FALSE);
   g_return_val_if_fail (GIMP_IS_SIZE_ENTRY (gsef->gse), FALSE);
